/*
 * ImageSender.h - image sender of the LOSSLESS DIGITAL IMAGE BROWSER
 *
 *  Author:    Rainer Lienhart, University of Mannheim, Germany
 *             (lienhart@pi4.informatik.uni-mannheim.de) or
 *             ICSI - International Computer Science Institue
 *             (lienhart@icsi.berkeley.edu)
 */

/* Copyright Notice
 * ================
 * Copyright 1994 by Rainer Lienhart
 * 
 * Permission to use, copy, and distribute LDIB in its entirety, for 
 * non-commercial purposes, is hereby granted without fee, provided that
 * this license information and copyright notice appear in all copies.
 * 
 * Note that distributing LDIB 'bundled' in with ANY product is considered
 * to be a 'commercial purpose'.
 *
 * The software may be modified for your own purposes, but modified
 * versions may NOT be distributed without prior consent of the author.
 * 
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the author be held liable for any damages
 * arising from the use of this software.
 * 
 * If you would like to do something with LDIB that this copyright
 * prohibits (such as distributing it with a commercial product), please
 * contact the author (preferably via email).  Arrangements can
 * probably be worked out.
 *
 * The author may be contacted via:
 *    Mail:     Rainer Lienhart
 *              Universitaet Mannheim
 *              Praktische Informatik IV
 *              68131 Mannheim
 *              Germany
 *
 *    Phone:    phone  : +49 621 292 1407
 *              fax    : +49 621 292 5745
 *    EMail:    lienhart@pi4.informatik.uni-mannheim.de
 */

#include <stdio.h>
#include <string.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/socket.h>
#include <sys/types.h>
#include <signal.h>
#include <netinet/in.h>
#include <netdb.h>
#include <unistd.h>
#include <fcntl.h>
#include "rcap.h"

#define TCP 6
#define MAXHOSTNAME 100
#define STRINGLENGTH 100

typedef struct {
  char *ImageName;  /* filename */
  long ImageSize;   /* in bytes */
} ImageEntry;

void Catch_SIGALRM ();
void Catch_SIGIO ();
int sendImage(int);
int tested_write(int fd, char *buf, int nbyte);
int tested_read(int fd, char *buf, int nbyte);
void FatalError (char *text);
void Syntax();
void Quit(int);
void Catch_SIGTERM ();
void policy1(int, int, long, rcapTraffic*, rcapRequirements *requirements);
void policy2(int, int, long, rcapTraffic*, rcapRequirements *requirements);
void policy3(int, int, long, rcapTraffic*, rcapRequirements *requirements);

ImageEntry *ImageList;
int numberOfImages = 0;
long maxImageSize = 0;

struct LatestCommandsType {
  int direction;
  void (*policy)(int, int, long, rcapTraffic*, rcapRequirements*);
  int position;
  int kill;
  int speed;
};
static struct LatestCommandsType latecom = {-1,NULL,-1,-1,0};
static struct timeval speed = {0,0};

#define FORWARD 1
#define BACKWARD 0
int direction = FORWARD;
int actImageNumber = 1;

static int s, cp, iv;
static char Text[STRINGLENGTH];
char          *cmd;
