/*
 * ImageViewer.h - image viewer of the LOSSLESS DIGITAL IMAGE BROWSER
 *
 *  Author:    Rainer Lienhart, University of Mannheim, Germany
 *             (lienhart@pi4.informatik.uni-mannheim.de) or
 *             ICSI - International Computer Science Institue
 *             (lienhart@icsi.berkeley.edu)
 */

/* Copyright Notice
 * ================
 * Copyright 1994 by Rainer Lienhart
 * 
 * Permission to use, copy, and distribute LDIB in its entirety, for 
 * non-commercial purposes, is hereby granted without fee, provided that
 * this license information and copyright notice appear in all copies.
 * 
 * Note that distributing LDIB 'bundled' in with ANY product is considered
 * to be a 'commercial purpose'.
 *
 * The software may be modified for your own purposes, but modified
 * versions may NOT be distributed without prior consent of the author.
 * 
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the author be held liable for any damages
 * arising from the use of this software.
 * 
 * If you would like to do something with LDIB that this copyright
 * prohibits (such as distributing it with a commercial product), please
 * contact the author (preferably via email).  Arrangements can
 * probably be worked out.
 *
 * The author may be contacted via:
 *    Mail:     Rainer Lienhart
 *              Universitaet Mannheim
 *              Praktische Informatik IV
 *              68131 Mannheim
 *              Germany
 *
 *    Phone:    phone  : +49 621 292 1407
 *              fax    : +49 621 292 5745
 *    EMail:    lienhart@pi4.informatik.uni-mannheim.de
 */

#include <stdio.h>
#include <strings.h>
#include <ctype.h>
#include <limits.h>

#include <sys/types.h>
#include <sys/time.h>
#include <sys/timeb.h>
#include <sys/stat.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <unistd.h>
#include <signal.h>
#include <fcntl.h>
#include <limits.h>

#include <X11/Xos.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/cursorfont.h>
#include "xv.h"

/* prototyping */
int HandleEvent(XEvent *event);
int LoadGIF(char *, PICINFO*);
int setupServerTCP(int);
int setupServerRTC(int);
int tested_read(int fd, char *buf, int nbyte);
int tested_write(int fd, char *buf, int nbyte);
void calcAndSendFPS();
int ImageDataAtSocketToRead (int t);
void Syntax(void);
void FatalError (char *function, char *text);
void Quit(int);
void CreateMainWindow(char *name,char *geom, int argc,char **argv);
void Resize(int w, int h);
int LoadPic();
void xvbzero(char*, int);
int changePalette(unsigned long *, int);
int ReadImageType();
int ReadImage(int, PICINFO *);
void Catch_SIGTERM ();

#define FONT "8x13"
#define TCP 6
#define MAXHOSTNAME 100
#define STRINGLENGTH 200

/* global memory for current image */
char speicher[1280*1024];

/* X stuff */
Display       *theDisp;
int           theScreen;
Colormap      theCmap;
Window        rootW, mainW;
GC            theGC;
unsigned long fcol,bcol;
Font          mfont;
XFontStruct   *mfinfo;
Visual        *theVisual;
int           theDepth;
unsigned long xmask = ExposureMask || ButtonPressMask || KeyPressMask;

/* global vars */
int            WIDE,HIGH;
char          *cmd, tmpstr[128];

Colormap def_colormap, my_colormap;
static XColor xcolor[256];
XImage *xi;
PICINFO picinfo[2], *test;
int ncolors;

int s, s2, is, cp;
char buffer[20000], dummy[100];
int CP_XID;
