#ifndef CONSTS_H
#define CONSTS_H
/*
 * $Header: /usr/src/local/tenet/rcap/rcapd/include/RCS/consts.h,v 2.0 1994/02/26 12:00:10 banerjea Exp $
 * consts.h
 * Anindo Banerjea (banerjea@tenet)
 *
 * This file contains constants like
 * The RCAP message types
 * Size of Records of Rcap Messages
 * Protocol types
 * Reasons for failure, error or SUCCESS
 * FSM states
 *
 * $Log: consts.h,v $
 * Revision 2.0  1994/02/26  12:00:10  banerjea
 * Rcap daemon. Version 2.0
 *
 * Revision 1.7  1994/02/26  09:00:55  banerjea
 * New release contains the following features
 * Release resource bug fix
 * CM support
 * RMTP fragmentation support
 * Enhanced robustness i.e. any control socket being closed
 * causes all channels going through in to go away.
 * support of reset_rcap which removes all channels in a node
 *
 * Revision 1.1  1994/02/10  00:00:33  banerjea
 * Initial revision
 *
 * Revision 1.6  1993/04/09  00:12:45  banerjea
 * Added a routing table error
 *
 * Revision 1.5  1993/02/02  19:14:34  banerjea
 * Added a constant MIN_BUFFER_RESERVATION which lower bounds the
 * number of buffers which are reserved on any channel. this makes sure
 * that rtip gets enough buffers to work correctly.
 *
 * Revision 1.4  1992/08/17  17:45:01  bmah
 * Added copyright stuff to keep the lawyers happy.
 *
 * Revision 1.3  1992/07/12  17:49:36  bmah
 * First RTIP-compatible daemon.  Some error codes added and fine-tuned.
 *
 * Copyright (c) 1992 Regents of the University of California
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research, and non-profit purposes and
 * without fee is hereby granted, provided that the above copyright
 * notice appear in all copies and that both that copyright notice and
 * this permission notice appear in supporting documentation, and that
 * the name of the University of California not be used in advertising
 * or publicity pertaining to distribution of the software without
 * specific, written prior permission.  Permission to incorporate this
 * software into commercial products can be obtained from the Campus
 * Software Office, 295 Evans Hall, University of California, Berkeley,
 * Ca., 94720 provided only that the the requestor give the University
 * of California a free licence to any derived software for educational
 * and research purposes.  The University of California makes no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied warranty.
 */

#include "stdio.h"
/*
 * Boolean values
 */
typedef unsigned char bool;
#define true 1
#define false 0


/* Some magic numbers */
#define WORST_CASE_UTIL  1.5 /* Used in the Buffer Calc and in det_test*/
#define MAX_DET_UTIL 1.0     /* Used in the det_test */
#define MAX_UTIL 1.0         /* Used in delay bound test */
#define MAX_NODE_UTIL 0.8    /* Used for the processor utilization cap */
#define MIN_BUFFER_RESERVATION 2 /* Used in buffer test to ensure atleast 2
				  * buffers are allocated in RTIP */

/* Identifying protocol constant for RCAP*/
#define RCAP_ID 101

/* 
 * RCAP message types
 */
#define ESTABLISH_REQUEST 102
#define ESTABLISH_DENIED  103
#define ESTABLISH_ACCEPT  104
#define CLOSE_REQUEST_FORWARD 105
#define CLOSE_REQUEST_REVERSE 106
#define STATUS_REQUEST 109
#define STATUS_REPORT 110

/* 
 * Size of records of RCAP messages in bytes
 */
#define SIZE_OF_RCAP_HEADER (7*4)
#define MIN_SIZE_OF_RMTP_HEADER_RECORD (12*4)
#define MIN_SIZE_OF_CMTP_HEADER_RECORD (11*4)
#define SIZE_OF_INTERNET_NSR (14*4)
#define SIZE_OF_INTERNET_ER (17*4)
#define SIZE_OF_INTERNET_SRR (11*4)
#define SIZE_OF_ESTABLISH_DENIED_BODY (1*4)
#define SIZE_OF_CLOSE_REQUEST_BODY (1*4)

/*
 * Protocol types
 */
#define PROTOCOL_RMTP 111
#define PROTOCOL_CMTP 112

/*
 * Reasons for failure, error or SUCCESS
 */
#define SUCCESS 1
#define FAIL_NO_AVAILABLE_VCIS 113
#define REASON_USER 115
#define REASON_NETFAIL 116
#define FAIL_DET        117
#define FAIL_STAT       118
#define FAIL_DELAY      119
#define FAIL_BUF        120
#define ERROR_UNKNOWN_GLOBAL_ID	121
#define ERROR_DUPLICATE_GLOBAL_ID	122
#define ERROR_RELAX_FAILED	124

#define ERROR_UNKNOWN_LCID 125
#define ERROR_DUPLICATE_LCID 126
#define FAIL_NODE_SATURATION  127
#define ERROR_ROUTING_TABLE 128

#define ERROR_NO_PORT 160
#define ERROR_PORT_IN_USE 161
#define ERROR_UNREGISTERED_PORT 162
#define ERROR_NO_MEMORY 163
#define ERROR_PROTOCOL 164
#define ERROR_RECEIVER 165
#define ERROR_TRANSPORT 166
#define ERROR_RELEASE_FAILED 167
#define ERROR_INIT 168
#define ERROR_CMTP_OPTION_NOT_SUPPORTED 169
#define ERROR_CMTP_CLIENT_BUFFER_LENGTH 170
#define ERROR_CMTP_DAEMON 171

#define REASON_SOCKET_KILLED 172
#define REASON_RCAP_RESET 173

/* Finite State Machine States */
#define FSM_INITIAL_STATE 130
#define FSM_TENTATIVE_STATE 131
#define FSM_PERMANENT_STATE 132
#define FSM_ERROR_STATE 133

/* SRR types */
#define SRR_TYPE_INET 140
#define SRR_TYPE_ATM 141

/* Network and subnetwork Levels */
#define FDDI 150
#define XUNET 151

/* Local communication constants */

#define LOCAL_RETURN 200
#define LOCAL_REGISTER 201
#define LOCAL_UNREGISTER 202
#define LOCAL_RECEIVE_REQUEST 203
#define LOCAL_RETURN_PARMS 204
#define LOCAL_ESTABLISH_RETURN 205
#define LOCAL_CM_ESTABLISH_RETURN 206
#define LOCAL_RESET_RCAP 207

#endif CONSTS_H
