#!/usr/local/bin/dpwish -f
# Program: ControlPanel
# Tcl version: 7.3 (Tcl/Tk/XF)
# Tk version: 3.6
# XF version: 2.2


#/*
# * ControlPanel.tcl - Control Panel of the LOSSLESS DIGITAL IMAGE BROWSER
# *
# *  Author:    Rainer Lienhart, University of Mannheim, Germany
# *             (lienhart@pi4.informatik.uni-mannheim.de) or
# *             ICSI - International Computer Science Institue
# *             (lienhart@icsi.berkeley.edu)
# */

#/* Copyright Notice
# * ================
# * Copyright 1994 by Rainer Lienhart
# * 
# * Permission to use, copy, and distribute LDIB in its entirety, for 
# * non-commercial purposes, is hereby granted without fee, provided that
# * this license information and copyright notice appear in all copies.
# * 
# * Note that distributing LDIB 'bundled' in with ANY product is considered
# * to be a 'commercial purpose'.
# *
# * The software may be modified for your own purposes, but modified
# * versions may NOT be distributed without prior consent of the author.
# * 
# * This software is provided 'as-is', without any express or implied
# * warranty.  In no event will the author be held liable for any damages
# * arising from the use of this software.
# * 
# * If you would like to do something with LDIB that this copyright
# * prohibits (such as distributing it with a commercial product), please
# * contact the author (preferably via email).  Arrangements can
# * probably be worked out.
# *
# * The author may be contacted via:
# *    Mail:     Rainer Lienhart
# *              Universitaet Mannheim
# *              Praktische Informatik IV
# *              68131 Mannheim
# *              Germany
# *
# *    Phone:    phone  : +49 621 292 1407
# *              fax    : +49 621 292 5745
# *    EMail:    lienhart@pi4.informatik.uni-mannheim.de
# */


if {[info exists env(LDIB_PATH)] == 0} {
  puts "---------------------------------------------------"
  puts "ERROR: Need environment variable LDIB_PATH"
  puts "Please set LDIB_PATH to the root directory of the LDIB"
  puts "For instance, by \"setenv LDIB_PATH <pathname>\""
  exit
}
global LDIB
set LDIB $env(LDIB_PATH)


# module inclusion
global env
global xfLoadPath
global xfLoadInfo
set xfLoadInfo 0
if {[info exists env(LDIB_PATH)]} {
  if {[string first $env(LDIB_PATH) ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/] == -1} {
    set xfLoadPath $env(LDIB_PATH):${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
  } {
    set xfLoadPath ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
  }
} {
  set xfLoadPath ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
}

global argc
global argv
global tkVersion
set tmpArgv ""
for {set counter 0} {$counter < $argc} {incr counter 1} {
  case [string tolower [lindex $argv $counter]] in {
    {-xfloadpath} {
      incr counter 1
      set xfLoadPath "[lindex $argv $counter]:$xfLoadPath"
    }
    {-xfstartup} {
      incr counter 1
      source [lindex $argv $counter]
    }
    {-xfbindfile} {
      incr counter 1
      set env(XF_BIND_FILE) "[lindex $argv $counter]"
    }
    {-xfcolorfile} {
      incr counter 1
      set env(XF_COLOR_FILE) "[lindex $argv $counter]"
    }
    {-xfcursorfile} {
      incr counter 1
      set env(XF_CURSOR_FILE) "[lindex $argv $counter]"
    }
    {-xffontfile} {
      incr counter 1
      set env(XF_FONT_FILE) "[lindex $argv $counter]"
    }
    {-xfmodelmono} {
      if {$tkVersion >= 3.0} {
        tk colormodel . monochrome
      }
    }
    {-xfmodelcolor} {
      if {$tkVersion >= 3.0} {
        tk colormodel . color
      }
    }
    {-xfloading} {
      set xfLoadInfo 1
    }
    {-xfnoloading} {
      set xfLoadInfo 0
    }
    {default} {
      lappend tmpArgv [lindex $argv $counter]
    }
  }
}
set argv $tmpArgv
set argc [llength $tmpArgv]
unset counter
unset tmpArgv


# procedure to show window .
proc ShowWindow. {args} {# xf ignore me 7
  global LDIB

  # Window manager configurations
  global tkVersion
  wm positionfrom . ""
  wm sizefrom . program
  wm geometry . 308x163
  wm iconbitmap . "@${LDIB}/bitmaps/Logo.bit"
  wm iconname . {Control Pannel}
  wm maxsize . 308 163
  wm minsize . 308 163
  wm title . {LDIB : Control Panel}


  . configure -background {#f0f0f0}
  bind . <Button-2> {VToplevel.top0 .policyWindow}

  # build widget .frame0
  frame .frame0 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}
  bind .frame0 <Button-2> {VToplevel.top0 .policyWindow}

  # build widget .frame0.frame15
  frame .frame0.frame15 \
    -background {#f0f0f0} \
    -borderwidth {2}
  bind .frame0.frame15 <Button-2> {VToplevel.top0 .policyWindow}

  # build widget .frame0.frame15.button23
  button .frame0.frame15.button23 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/pause.bit" \
    -borderwidth {1} \
    -command { pauseButton } \
    -font {6x13} \
    -foreground {#000000} \
    -text {button23}
  # bindings
  bind .frame0.frame15.button23 <Button-2> {VToplevel.top0 .policyWindow}

  # build widget .frame0.frame15.button24
  button .frame0.frame15.button24 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/start.bit" \
    -borderwidth {1} \
    -command { startButton } \
    -font {6x13} \
    -foreground {#000000} \
    -text {button24}

  # build widget .frame0.frame15.button25
  button .frame0.frame15.button25 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/backward.bit" \
    -borderwidth {1} \
    -command { backwardButton } \
    -font {6x13} \
    -foreground {#000000} \
    -text {button25}
  bind .frame0.frame15.button25 <Button-2> {VToplevel.top0 .policyWindow}

  # build widget .frame0.frame15.button26
  button .frame0.frame15.button26 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/forward.bit" \
    -borderwidth {1} \
    -command { forwardButton } \
    -font {6x13} \
    -foreground {#000000} \
    -text {button26}
  bind .frame0.frame15.button26 <Button-2> {VToplevel.top0 .policyWindow}

  # build widget .frame0.frame15.button27
  button .frame0.frame15.button27 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/end.bit" \
    -borderwidth {1} \
    -command { endButton } \
    -font {6x13} \
    -foreground {#000000} \
    -text {button27}
  bind .frame0.frame15.button27 <Button-2> {VToplevel.top0 .policyWindow}

  # build widget .frame0.frame15.button0
  button .frame0.frame15.button0 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/eject.bit" \
    -borderwidth {1} \
    -command { ejectButton } \
    -font {6x13} \
    -foreground {#000000} \
    -text {button0}
  bind .frame0.frame15.button0 <Button-2> {VToplevel.top0 .policyWindow}

  # pack widget .frame0.frame15
  pack append .frame0.frame15 \
    .frame0.frame15.button23 {left frame center padx 10 pady 5} \
    .frame0.frame15.button24 {left frame center padx 10 pady 5} \
    .frame0.frame15.button25 {left frame center padx 10 pady 5} \
    .frame0.frame15.button26 {left frame center padx 10 pady 5} \
    .frame0.frame15.button27 {left frame center padx 10 pady 5} \
    .frame0.frame15.button0 {left frame center padx 10}

  # build widget .frame0.scale22
  scale .frame0.scale22 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {#global mode  globale pause  if {($mode == "STOP") && ($pause == "OFF")} {sendSpeed}  } \
    -font {6x13} \
    -foreground {#000000} \
    -label {Images per 10 seconds: } \
    -length {276} \
    -orient {horizontal} \
    -relief {raised} \
    -sliderlength {20} \
    -to {300} \
    -width {8}
  # bindings
  bind .frame0.scale22 <ButtonRelease-1> {if {$mode == "STOP"} {sendSpeed [.frame0.scale22 get]}}
  bind .frame0.scale22 <Button-2> {VToplevel.top0 .policyWindow}

  # build widget .frame0.scale23
  scale .frame0.scale23 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {} \
    -font {6x13} \
    -foreground {#000000} \
    -label {Image Number:} \
    -length {276} \
    -orient {horizontal} \
    -relief {raised} \
    -sliderlength {20} \
    -to {13} \
    -width {8}
  # bindings
  bind .frame0.scale23 <ButtonRelease-1> {sendPosition [.frame0.scale23 get]}
  bind .frame0.scale23 <Button-2> {VToplevel.top0 .policyWindow}

  # pack widget .frame0
  pack append .frame0 \
    .frame0.frame15 {top frame center} \
    .frame0.scale22 {top frame center padx 10 pady 10} \
    .frame0.scale23 {top frame center padx 10 pady 10}

  # pack widget .
  pack append . \
    .frame0 {top frame center padx 10 pady 10}

  if {"[info procs XFEdit]" != ""} {
    catch "XFMiscBindWidgetTree ."
    after 2 "catch {XFEditSetShowWindows}"
  }
}


# User defined procedures
# look up in LDIB/procedure/ControlPanel.procs

# Internal procedures


# Procedure: Alias
if {"[info procs Alias]" == ""} {
proc Alias { args} {
# xf ignore me 7
##########
# Procedure: Alias
# Description: establish an alias for a procedure
# Arguments: args - no argument means that a list of all aliases
#                   is returned. Otherwise the first parameter is
#                   the alias name, and the second parameter is
#                   the procedure that is aliased.
# Returns: nothing, the command that is bound to the alias or a
#          list of all aliases - command pairs. 
# Sideeffects: internalAliasList is updated, and the alias
#              proc is inserted
##########
  global internalAliasList

  if {[llength $args] == 0} {
    return $internalAliasList
  } {
    if {[llength $args] == 1} {
      set xfTmpIndex [lsearch $internalAliasList "[lindex $args 0] *"]
      if {$xfTmpIndex != -1} {
        return [lindex [lindex $internalAliasList $xfTmpIndex] 1]
      }
    } {
      if {[llength $args] == 2} {
        eval "proc [lindex $args 0] {args} {#xf ignore me 4
return \[eval \"[lindex $args 1] \$args\"\]}"
        set xfTmpIndex [lsearch $internalAliasList "[lindex $args 0] *"]
        if {$xfTmpIndex != -1} {
          set internalAliasList [lreplace $internalAliasList $xfTmpIndex $xfTmpIndex "[lindex $args 0] [lindex $args 1]"]
        } {
          lappend internalAliasList "[lindex $args 0] [lindex $args 1]"
        }
      } {
        error "Alias: wrong number or args: $args"
      }
    }
  }
}
}


# Procedure: GetSelection
if {"[info procs GetSelection]" == ""} {
proc GetSelection {} {
# xf ignore me 7
##########
# Procedure: GetSelection
# Description: get current selection
# Arguments: none
# Returns: none
# Sideeffects: none
##########

  # the save way
  set xfSelection ""
  catch "selection get" xfSelection
  if {"$xfSelection" == "selection doesn't exist or form \"STRING\" not defined"} {
    return ""
  } {
    return $xfSelection
  }
}
}


# Procedure: MenuPopupAdd
if {"[info procs MenuPopupAdd]" == ""} {
proc MenuPopupAdd { xfW xfButton xfMenu {xfModifier ""} {xfCanvasTag ""}} {
# xf ignore me 7
# the popup menu handling is from (I already gave up with popup handling :-):
#
# Copyright 1991,1992 by James Noble.
# Everyone is granted permission to copy, modify and redistribute.
# This notice must be preserved on all copies or derivates.
#
##########
# Procedure: MenuPopupAdd
# Description: attach a popup menu to widget
# Arguments: xfW - the widget
#            xfButton - the button we use
#            xfMenu - the menu to attach
#            {xfModifier} - a optional modifier
#            {xfCanvasTag} - a canvas tagOrId
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  set tk_popupPriv($xfMenu,focus) ""
  set tk_popupPriv($xfMenu,grab) ""
  if {"$xfModifier" != ""} {
    set press "$xfModifier-"
    set motion "$xfModifier-"
    set release "Any-"
  } {
    set press ""
    set motion ""
    set release ""
  }

  bind $xfMenu "<${motion}B${xfButton}-Motion>"  "MenuPopupMotion $xfMenu %W %X %Y"
  bind $xfMenu "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  if {"$xfCanvasTag" == ""} {
    bind $xfW "<${press}ButtonPress-${xfButton}>"  "MenuPopupPost $xfMenu %X %Y"
    bind $xfW "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  } {
    $xfW bind $xfCanvasTag "<${press}ButtonPress-${xfButton}>"  "MenuPopupPost $xfMenu %X %Y"
    $xfW bind $xfCanvasTag "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  }
}
}


# Procedure: MenuPopupMotion
if {"[info procs MenuPopupMotion]" == ""} {
proc MenuPopupMotion { xfMenu xfW xfX xfY} {
# xf ignore me 7
##########
# Procedure: MenuPopupMotion
# Description: handle the popup menu motion
# Arguments: xfMenu - the topmost menu
#            xfW - the menu
#            xfX - the root x coordinate
#            xfY - the root x coordinate
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  if {"[info commands $xfW]" != "" && [winfo ismapped $xfW] &&
      "[winfo class $xfW]" == "Menu" &&
      [info exists tk_popupPriv($xfMenu,focus)] &&
      "$tk_popupPriv($xfMenu,focus)" != "" &&
      [info exists tk_popupPriv($xfMenu,grab)] &&
      "$tk_popupPriv($xfMenu,grab)" != ""} {
    set xfPopMinX [winfo rootx $xfW]
    set xfPopMaxX [expr $xfPopMinX+[winfo width $xfW]]
    if {$xfX >= $xfPopMinX && $xfX <= $xfPopMaxX} {
      $xfW activate @[expr $xfY-[winfo rooty $xfW]]
      if {![catch "$xfW entryconfig @[expr $xfY-[winfo rooty $xfW]] -menu" result]} {
        if {"[lindex $result 4]" != ""} {
          foreach binding [bind $xfMenu] {
            bind [lindex $result 4] $binding [bind $xfMenu $binding]
          }
        }
      }
    } {
      $xfW activate none
    }
  }
}
}


# Procedure: MenuPopupPost
if {"[info procs MenuPopupPost]" == ""} {
proc MenuPopupPost { xfMenu xfX xfY} {
# xf ignore me 7
##########
# Procedure: MenuPopupPost
# Description: post the popup menu
# Arguments: xfMenu - the menu
#            xfX - the root x coordinate
#            xfY - the root x coordinate
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  if {"[info commands $xfMenu]" != ""} {
    if {![info exists tk_popupPriv($xfMenu,focus)]} {
      set tk_popupPriv($xfMenu,focus) [focus]
    } {
      if {"$tk_popupPriv($xfMenu,focus)" == ""} {
        set tk_popupPriv($xfMenu,focus) [focus]
      }
    }
    set tk_popupPriv($xfMenu,grab) $xfMenu

    catch "$xfMenu activate none"
    catch "$xfMenu post $xfX $xfY"
    catch "focus $xfMenu"
    catch "grab -global $xfMenu"
  }
}
}


# Procedure: MenuPopupRelease
if {"[info procs MenuPopupRelease]" == ""} {
proc MenuPopupRelease { xfMenu xfW} {
# xf ignore me 7
##########
# Procedure: MenuPopupRelease
# Description: remove the popup menu
# Arguments: xfMenu - the topmost menu widget
#            xfW - the menu widget
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv
  global tkVersion

  if {"[info commands $xfW]" != "" && [winfo ismapped $xfW] &&
      "[winfo class $xfW]" == "Menu" &&
      [info exists tk_popupPriv($xfMenu,focus)] &&
      "$tk_popupPriv($xfMenu,focus)" != "" &&
      [info exists tk_popupPriv($xfMenu,grab)] &&
      "$tk_popupPriv($xfMenu,grab)" != ""} {
    if {$tkVersion >= 3.0} {
      catch "grab release $tk_popupPriv($xfMenu,grab)"
    } {
      catch "grab none"
    }
    catch "focus $tk_popupPriv($xfMenu,focus)"
    set tk_popupPriv($xfMenu,focus) ""
    set tk_popupPriv($xfMenu,grab) ""
    if {"[$xfW index active]" != "none"} {
      $xfW invoke active; catch "$xfMenu unpost"
    }
  }
  catch "$xfMenu unpost"
}
}


# Procedure: NoFunction
if {"[info procs NoFunction]" == ""} {
proc NoFunction { args} {
# xf ignore me 7
##########
# Procedure: NoFunction
# Description: do nothing (especially with scales and scrollbars)
# Arguments: args - a number of ignored parameters
# Returns: none
# Sideeffects: none
##########
}
}


# Procedure: SN
if {"[info procs SN]" == ""} {
proc SN { {xfName ""}} {
# xf ignore me 7
##########
# Procedure: SN
# Description: map a symbolic name to the widget path
# Arguments: xfName
# Returns: the symbolic name
# Sideeffects: none
##########

  SymbolicName $xfName
}
}


# Procedure: SymbolicName
if {"[info procs SymbolicName]" == ""} {
proc SymbolicName { {xfName ""}} {
# xf ignore me 7
##########
# Procedure: SymbolicName
# Description: map a symbolic name to the widget path
# Arguments: xfName
# Returns: the symbolic name
# Sideeffects: none
##########

  global symbolicName

  if {"$xfName" != ""} {
    set xfArrayName ""
    append xfArrayName symbolicName ( $xfName )
    if {![catch "set \"$xfArrayName\"" xfValue]} {
      return $xfValue
    } {
      if {"[info commands XFProcError]" != ""} {
        XFProcError "Unknown symbolic name:\n$xfName"
      } {
        puts stderr "XF error: unknown symbolic name:\n$xfName"
      }
    }
  }
  return ""
}
}


# Procedure: Unalias
if {"[info procs Unalias]" == ""} {
proc Unalias { aliasName} {
# xf ignore me 7
##########
# Procedure: Unalias
# Description: remove an alias for a procedure
# Arguments: aliasName - the alias name to remove
# Returns: none
# Sideeffects: internalAliasList is updated, and the alias
#              proc is removed
##########
  global internalAliasList

  set xfIndex [lsearch $internalAliasList "$aliasName *"]
  if {$xfIndex != -1} {
    rename $aliasName ""
    set internalAliasList [lreplace $internalAliasList $xfIndex $xfIndex]
  }
}
}



# startup source
proc StartupSrc {args} {

}


# end source
proc EndSrc {} {
global argc argv argv0
global imageSender imageSenderPort
global imageViewer imageViewerPort

for {set counter 0} {$counter < $argc} {incr counter 1} {
  case [string tolower [lindex $argv $counter]] in {
    {-imagesender} {
      incr counter 1
      set imageSender "[lindex $argv $counter]" 	
    }
    {-is} {
      incr counter 1
      set imageSender "[lindex $argv $counter]" 	
    }
    {-imagesenderport} {
      incr counter 1
      set imageSenderPort "[lindex $argv $counter]" 	
    }
    {-isp} {
      incr counter 1
      set imageSenderPort "[lindex $argv $counter]" 	
    }
    {-imageviewerport} {
      incr counter 1
      set imageViewerPort "[lindex $argv $counter]" 	
    }
    {-ivp} {
      incr counter 1
      set imageViewerPort "[lindex $argv $counter]" 	
    }
    {-imageviewer} {
      incr counter 1
      set imageViewer "[lindex $argv $counter]" 	
    }
    {-iv} {
      incr counter 1
      set imageViewer "[lindex $argv $counter]" 	
    }
    {-tracefile} {
      incr counter 1
      set traceName "[lindex $argv $counter]" 	
    }
    {-tf} {
      incr counter 1
      set traceName "[lindex $argv $counter]" 	
    }
     {default} {
      puts "SYNOPSIS : $argv0"
      puts {           -imagesender <host address> -imagesenderport <int>}
      puts {           -imageviewer <host address> -imageviewerport <int>}
      puts {           [-tracefile <filename>]}
      puts {OR}
      puts "SYNOPSIS : $argv0"
      puts {           -is <host address> -isp <int>}
      puts {           -iv <host address> -ivp <int>}
      puts {           [-tf <filename>]}
      # Nothing has been opened up to now
      exit 
    }
  }
}
if {$argc < 8} {
      puts "SYNOPSIS : $argv0"
      puts {           -imagesender <host address> -imagesenderport <int>}
      puts {           -imageviewer <host address> -imageviewerport <int>}
      puts {           [-tracefile <filename>]}
      puts {OR}
      puts "SYNOPSIS : $argv0"
      puts {           -is <host address> -isp <int>}
      puts {           -iv <host address> -ivp <int>}
      puts {           [-tf <filename>]}
      # Nothing has been opened up to now
      exit 
}
install
}

# prepare auto loading
global auto_path
global tk_library
global xfLoadPath
foreach xfElement [eval list [split $xfLoadPath :] $auto_path] {
  if {[file exists $xfElement/tclIndex]} {
    lappend auto_path $xfElement
  }
}
catch "unset auto_index"

catch "unset auto_oldpath"

catch "unset auto_execs"

XFLocalIncludeModule "ControlPanel.procs"
XFLocalIncludeModule fatalError
XFLocalIncludeModule "PolicyInfoWindow"
XFLocalIncludeModule Copyright

# startup source
StartupSrc

# initialize global variables
proc InitGlobals {} {
  global {direction}
  set {direction} {FORWARD}
  global {errortext}
  set {errortext} {}
  global {mode}
  set {mode} {EJECT}
  global {numberOfImages}
  set {numberOfImages} {14}
  global {pause}
  set {pause} {OFF}
  global {result}
  set {result} {}
  global {sockid}
  set {sockid} {}
  global fps
  set fps 0
  global ave_fps
  set ave_fps 0
  global policy
  set policy 1
  global traceName
  set traceName {CP.log.LDIB}

  # please don't modify the following
  # variables. They are needed by xf.
  global {autoLoadList}
  set {autoLoadList(ControlPanel.tcl)} {0}
  global {internalAliasList}
  set {internalAliasList} {}
  global {moduleList}
  set {moduleList(ControlPanel.tcl)} {}
  global {preloadList}
  set {preloadList(xfInternal)} {}
  global {symbolicName}
  set {symbolicName(root)} {.}
  global {xfWmSetPosition}
  set {xfWmSetPosition} {}
  global {xfWmSetSize}
  set {xfWmSetSize} {.}
  global {xfAppDefToplevels}
  set {xfAppDefToplevels} {}
}

# initialize global variables
InitGlobals

# display/remove toplevel windows.
tk colormodel . monochrome
ShowWindow.

# load default bindings.
if {[info exists env(XF_BIND_FILE)] &&
    "[info procs XFShowHelp]" == ""} {
  source $env(XF_BIND_FILE)
}

# end source
EndSrc

# eof
#

