#!/usr/local/bin/dpwish -f
# Program: NameServer4
# Tcl version: 7.3 (Tcl/Tk/XF)
# Tk version: 3.6
# XF version: 2.2
#


#/*
# *  NameServer.tcl - Name Server of the LOSSLESS DIGITAL IMAGE BROWSER
# *
# *  Author:    Rainer Lienhart, University of Mannheim, Germany
# *             (lienhart@pi4.informatik.uni-mannheim.de) or
# *             ICSI - International Computer Science Institue
# *             (lienhart@icsi.berkeley.edu)
# */

#/* Copyright Notice
# * ================
# * Copyright 1994 by Rainer Lienhart
# * 
# * Permission to use, copy, and distribute LDIB in its entirety, for 
# * non-commercial purposes, is hereby granted without fee, provided that
# * this license information and copyright notice appear in all copies.
# * 
# * Note that distributing LDIB 'bundled' in with ANY product is considered
# * to be a 'commercial purpose'.
# *
# * The software may be modified for your own purposes, but modified
# * versions may NOT be distributed without prior consent of the author.
# * 
# * This software is provided 'as-is', without any express or implied
# * warranty.  In no event will the author be held liable for any damages
# * arising from the use of this software.
# * 
# * If you would like to do something with LDIB that this copyright
# * prohibits (such as distributing it with a commercial product), please
# * contact the author (preferably via email).  Arrangements can
# * probably be worked out.
# *
# * The author may be contacted via:
# *    Mail:     Rainer Lienhart
# *              Universitaet Mannheim
# *              Praktische Informatik IV
# *              68131 Mannheim
# *              Germany
# *
# *    Phone:    phone  : +49 621 292 1407
# *              fax    : +49 621 292 5745
# *    EMail:    lienhart@pi4.informatik.uni-mannheim.de
# */


if {[info exists env(LDIB_PATH)] == 0} {
  puts "---------------------------------------------------"
  puts "ERROR: Need environment variable LDIB_PATH"
  puts "Please set LDIB_PATH to the root directory of the LDIB"
  puts "For instance, by \"setenv LDIB_PATH <pathname>\""
  exit
}
global LDIB
set LDIB $env(LDIB_PATH)

# module inclusion
global env
global xfLoadPath
global xfLoadInfo
set xfLoadInfo 0
if {[info exists env(LDIB_PATH)]} {
  if {[string first $env(LDIB_PATH) ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/] == -1} {
    set xfLoadPath $env(LDIB_PATH):${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
  } {
    set xfLoadPath ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
  }
} {
  set xfLoadPath ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
}

global argc
global argv
global tkVersion
set tmpArgv ""
for {set counter 0} {$counter < $argc} {incr counter 1} {
  case [string tolower [lindex $argv $counter]] in {
    {-xfloadpath} {
      incr counter 1
      set xfLoadPath "[lindex $argv $counter]:$xfLoadPath"
    }
    {-xfstartup} {
      incr counter 1
      source [lindex $argv $counter]
    }
    {-xfbindfile} {
      incr counter 1
      set env(XF_BIND_FILE) "[lindex $argv $counter]"
    }
    {-xfcolorfile} {
      incr counter 1
      set env(XF_COLOR_FILE) "[lindex $argv $counter]"
    }
    {-xfcursorfile} {
      incr counter 1
      set env(XF_CURSOR_FILE) "[lindex $argv $counter]"
    }
    {-xffontfile} {
      incr counter 1
      set env(XF_FONT_FILE) "[lindex $argv $counter]"
    }
    {-xfmodelmono} {
      if {$tkVersion >= 3.0} {
        tk colormodel . monochrome
      }
    }
    {-xfmodelcolor} {
      if {$tkVersion >= 3.0} {
        tk colormodel . color
      }
    }
    {-xfloading} {
      set xfLoadInfo 1
    }
    {-xfnoloading} {
      set xfLoadInfo 0
    }
    {default} {
      lappend tmpArgv [lindex $argv $counter]
    }
  }
}
set argv $tmpArgv
set argc [llength $tmpArgv]
unset counter
unset tmpArgv


# procedure to show window .
proc ShowWindow. {args} {# xf ignore me 7
global LDIB

  # Window manager configurations
  global tkVersion
  wm positionfrom . ""
  wm sizefrom . ""
  wm geometry . 460x400
  wm iconbitmap . @${LDIB}/bitmaps/Logo.bit
  wm iconname . {LDIB: Name Server}
  wm maxsize . 1024 768
  wm minsize . 460 400
  wm title . {LDIB: Name Server}


  # build widget .frame0
  frame .frame0 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame0.frame7
  frame .frame0.frame7 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}
  bind .frame0.frame7 <Button-1> { copyrightWindow .copyright }
  bind .frame0.frame7 <Button-2> { copyrightWindow .copyright }
  bind .frame0.frame7 <Button-3> { copyrightWindow .copyright }

  # build widget .frame0.label8
  label .frame0.label8 \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/Logo.bit" \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {label8}
  bind .frame0.label8 <Button-1> { copyrightWindow .copyright }
  bind .frame0.label8 <Button-2> { copyrightWindow .copyright }
  bind .frame0.label8 <Button-3> { copyrightWindow .copyright }

  # build widget .frame0.label9
  label .frame0.label9 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text { LOSSLESS DIGITAL IMAGE BROWSER}
  bind .frame0.label9 <Button-1> { copyrightWindow .copyright }
  bind .frame0.label9 <Button-2> { copyrightWindow .copyright }
  bind .frame0.label9 <Button-3> { copyrightWindow .copyright }

  # build widget .frame0.frame10
  frame .frame0.frame10 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}
  bind .frame0.frame10 <Button-1> { copyrightWindow .copyright }
  bind .frame0.frame10 <Button-2> { copyrightWindow .copyright }
  bind .frame0.frame10 <Button-3> { copyrightWindow .copyright }

  # pack widget .frame0
  pack append .frame0 \
    .frame0.frame7 {left frame center expand fillx} \
    .frame0.label8 {left frame center} \
    .frame0.label9 {left frame center} \
    .frame0.frame10 {left frame center expand fillx}

  # build widget .frame2
  frame .frame2 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame2.frame1
  frame .frame2.frame1 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame2.frame1.label4
  label .frame2.frame1.label4 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {Name Server Address:}

  # build widget .frame2.frame1.label5
  label .frame2.frame1.label5 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {label5} \
    -textvariable {nameOfMine}

  # pack widget .frame2.frame1
  pack append .frame2.frame1 \
    .frame2.frame1.label4 {left frame w padx 10} \
    .frame2.frame1.label5 {left frame center}

  # build widget .frame2.frame4
  frame .frame2.frame4 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame2.frame4.label6
  label .frame2.frame4.label6 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {Name Server Portnumber:}

  # build widget .frame2.frame4.label7
  label .frame2.frame4.label7 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {8765} \
    -textvariable {nameServerPort}

  # pack widget .frame2.frame4
  pack append .frame2.frame4 \
    .frame2.frame4.label6 {left frame center} \
    .frame2.frame4.label7 {left frame center padx 10}

  # build widget .frame2.frame6
  frame .frame2.frame6 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame2.frame6.label3
  label .frame2.frame6.label3 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {Test every  }

  # build widget .frame2.frame6.entry4
  entry .frame2.frame6.entry4 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -insertborderwidth {1} \
    -relief {sunken} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -textvariable {checkIntervall} \
    -width {10}
  # bindings
  bind .frame2.frame6.entry4 <Key-Return> {checkServer}

  # build widget .frame2.frame6.label5
  label .frame2.frame6.label5 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text { seconds if Image Servers are still alive.}

  # pack widget .frame2.frame6
  pack append .frame2.frame6 \
    .frame2.frame6.label3 {left frame center} \
    .frame2.frame6.entry4 {left frame center} \
    .frame2.frame6.label5 {left frame center}

  # build widget .frame2.frame
  frame .frame2.frame \
    -background {#f0f0f0} \
    -borderwidth {1}

  # build widget .frame2.frame.label4
  label .frame2.frame.label4 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -padx {2} \
    -text {Message:}

  # build widget .frame2.frame.message9
  message .frame2.frame.message9 \
    -aspect {1400} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -padx {5} \
    -pady {2} \
    -text {icsib71.ICSI.Berkeley.EDU ist working} \
    -textvariable {statusWord}

  # pack widget .frame2.frame
  pack append .frame2.frame \
    .frame2.frame.label4 {left frame nw} \
    .frame2.frame.message9 {left frame center}

  # pack widget .frame2
  pack append .frame2 \
    .frame2.frame1 {top frame center fill} \
    .frame2.frame4 {top frame center fill} \
    .frame2.frame6 {top frame center fillx} \
    .frame2.frame {top frame center fill}

  # build widget .frame3
  frame .frame3 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame3.label1
  label .frame3.label1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {List of active Image Servers:}
  bind .frame3.label1 <Button-2> {change&showListbox}

  # build widget .frame3.frame
  frame .frame3.frame \
    -background {#f0f0f0} \
    -borderwidth {1}
  bind .frame3.frame <Button-2> {change&showListbox}

  # build widget .frame3.frame.scrollbar3
  scrollbar .frame3.frame.scrollbar3 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {MoveBothListboxes} \
    -foreground {#b0b0b0} \
    -orient {horizontal} \
    -relief {raised} \
    -width {12}
  bind .frame3.frame.scrollbar3 <Button-2> {change&showListbox}

  # build widget .frame3.frame.scrollbar2
  scrollbar .frame3.frame.scrollbar2 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame3.frame.listbox1 yview} \
    -foreground {#b0b0b0} \
    -relief {raised} \
    -width {12}
  bind .frame3.frame.scrollbar2 <Button-2> {change&showListbox}

  # build widget .frame3.frame.listbox0
  listbox .frame3.frame.listbox0 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -geometry {10x1} \
    -relief {raised} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -xscrollcommand {.frame3.frame.scrollbar3 set} \
    -yscrollcommand {.frame3.frame.scrollbar2 set}
  bind .frame3.frame.listbox0 <Button-2> {change&showListbox}

  # build widget .frame3.frame.listbox1
  listbox .frame3.frame.listbox1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -relief {raised} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -xscrollcommand {.frame3.frame.scrollbar3 set} \
    -yscrollcommand {.frame3.frame.scrollbar2 set}
  bind .frame3.frame.listbox1 <Button-2> {change&showListbox}

  # pack widget .frame3.frame
  pack append .frame3.frame \
    .frame3.frame.scrollbar2 {right frame center filly} \
    .frame3.frame.scrollbar3 {bottom frame center fillx} \
    .frame3.frame.listbox0 {top frame center fillx} \
    .frame3.frame.listbox1 {top frame center expand fill}

  # pack widget .frame3
  pack append .frame3 \
    .frame3.label1 {top frame nw} \
    .frame3.frame {bottom frame center expand fill}

  # build widget .frame1
  frame .frame1 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame1.button3
  button .frame1.button3 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {terminateNameServer} \
    -font {6x13} \
    -foreground {#000000} \
    -text {Terminate Name Server}

  # pack widget .frame1
  pack append .frame1 \
    .frame1.button3 {top frame center pady 10}

  # pack widget .
  pack append . \
    .frame0 {top frame center fillx} \
    .frame2 {top frame center fillx} \
    .frame3 {top frame center expand fill} \
    .frame1 {top frame center fillx}

  .frame3.frame.listbox0 insert end {Name of Server                             portnumber         working since                 .}
  .frame3.frame.listbox1 insert end {icsib71.ICSI.Berkeley.EDU                  128.32.201.197     Fri Apr 15 17:36:50 PDT 1994  }



  if {"[info procs XFEdit]" != ""} {
    catch "XFMiscBindWidgetTree ."
    after 2 "catch {XFEditSetShowWindows}"
  }
}


# User defined procedures

#-------------------------------------------------------------------
# Procedure: MoveBothListboxes
proc MoveBothListboxes { args} {
.frame3.frame.listbox1 xview $args
.frame3.frame.listbox0 xview $args
}


#-------------------------------------------------------------------
# Procedure: ServerListbox
proc ServerListbox { args} {
#xf ignore me 4
return [eval ".frame3.frame.listbox1 $args"]
}


#-------------------------------------------------------------------
# Procedure: ServerListboxTitle
proc ServerListboxTitle { args} {
#xf ignore me 4
return [eval ".frame3.frame.listbox0 $args"]
}
# more can be found in LDIB/procedures/NameServer.procs

# Internal procedures


# Procedure: Alias
if {"[info procs Alias]" == ""} {
proc Alias { args} {
# xf ignore me 7
##########
# Procedure: Alias
# Description: establish an alias for a procedure
# Arguments: args - no argument means that a list of all aliases
#                   is returned. Otherwise the first parameter is
#                   the alias name, and the second parameter is
#                   the procedure that is aliased.
# Returns: nothing, the command that is bound to the alias or a
#          list of all aliases - command pairs. 
# Sideeffects: internalAliasList is updated, and the alias
#              proc is inserted
##########
  global internalAliasList

  if {[llength $args] == 0} {
    return $internalAliasList
  } {
    if {[llength $args] == 1} {
      set xfTmpIndex [lsearch $internalAliasList "[lindex $args 0] *"]
      if {$xfTmpIndex != -1} {
        return [lindex [lindex $internalAliasList $xfTmpIndex] 1]
      }
    } {
      if {[llength $args] == 2} {
        eval "proc [lindex $args 0] {args} {#xf ignore me 4
return \[eval \"[lindex $args 1] \$args\"\]}"
        set xfTmpIndex [lsearch $internalAliasList "[lindex $args 0] *"]
        if {$xfTmpIndex != -1} {
          set internalAliasList [lreplace $internalAliasList $xfTmpIndex $xfTmpIndex "[lindex $args 0] [lindex $args 1]"]
        } {
          lappend internalAliasList "[lindex $args 0] [lindex $args 1]"
        }
      } {
        error "Alias: wrong number or args: $args"
      }
    }
  }
}
}


# Procedure: GetSelection
if {"[info procs GetSelection]" == ""} {
proc GetSelection {} {
# xf ignore me 7
##########
# Procedure: GetSelection
# Description: get current selection
# Arguments: none
# Returns: none
# Sideeffects: none
##########

  # the save way
  set xfSelection ""
  catch "selection get" xfSelection
  if {"$xfSelection" == "selection doesn't exist or form \"STRING\" not defined"} {
    return ""
  } {
    return $xfSelection
  }
}
}


# Procedure: MenuPopupAdd
if {"[info procs MenuPopupAdd]" == ""} {
proc MenuPopupAdd { xfW xfButton xfMenu {xfModifier ""} {xfCanvasTag ""}} {
# xf ignore me 7
# the popup menu handling is from (I already gave up with popup handling :-):
#
# Copyright 1991,1992 by James Noble.
# Everyone is granted permission to copy, modify and redistribute.
# This notice must be preserved on all copies or derivates.
#
##########
# Procedure: MenuPopupAdd
# Description: attach a popup menu to widget
# Arguments: xfW - the widget
#            xfButton - the button we use
#            xfMenu - the menu to attach
#            {xfModifier} - a optional modifier
#            {xfCanvasTag} - a canvas tagOrId
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  set tk_popupPriv($xfMenu,focus) ""
  set tk_popupPriv($xfMenu,grab) ""
  if {"$xfModifier" != ""} {
    set press "$xfModifier-"
    set motion "$xfModifier-"
    set release "Any-"
  } {
    set press ""
    set motion ""
    set release ""
  }

  bind $xfMenu "<${motion}B${xfButton}-Motion>"  "MenuPopupMotion $xfMenu %W %X %Y"
  bind $xfMenu "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  if {"$xfCanvasTag" == ""} {
    bind $xfW "<${press}ButtonPress-${xfButton}>"  "MenuPopupPost $xfMenu %X %Y"
    bind $xfW "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  } {
    $xfW bind $xfCanvasTag "<${press}ButtonPress-${xfButton}>"  "MenuPopupPost $xfMenu %X %Y"
    $xfW bind $xfCanvasTag "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  }
}
}


# Procedure: MenuPopupMotion
if {"[info procs MenuPopupMotion]" == ""} {
proc MenuPopupMotion { xfMenu xfW xfX xfY} {
# xf ignore me 7
##########
# Procedure: MenuPopupMotion
# Description: handle the popup menu motion
# Arguments: xfMenu - the topmost menu
#            xfW - the menu
#            xfX - the root x coordinate
#            xfY - the root x coordinate
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  if {"[info commands $xfW]" != "" && [winfo ismapped $xfW] &&
      "[winfo class $xfW]" == "Menu" &&
      [info exists tk_popupPriv($xfMenu,focus)] &&
      "$tk_popupPriv($xfMenu,focus)" != "" &&
      [info exists tk_popupPriv($xfMenu,grab)] &&
      "$tk_popupPriv($xfMenu,grab)" != ""} {
    set xfPopMinX [winfo rootx $xfW]
    set xfPopMaxX [expr $xfPopMinX+[winfo width $xfW]]
    if {$xfX >= $xfPopMinX && $xfX <= $xfPopMaxX} {
      $xfW activate @[expr $xfY-[winfo rooty $xfW]]
      if {![catch "$xfW entryconfig @[expr $xfY-[winfo rooty $xfW]] -menu" result]} {
        if {"[lindex $result 4]" != ""} {
          foreach binding [bind $xfMenu] {
            bind [lindex $result 4] $binding [bind $xfMenu $binding]
          }
        }
      }
    } {
      $xfW activate none
    }
  }
}
}


# Procedure: MenuPopupPost
if {"[info procs MenuPopupPost]" == ""} {
proc MenuPopupPost { xfMenu xfX xfY} {
# xf ignore me 7
##########
# Procedure: MenuPopupPost
# Description: post the popup menu
# Arguments: xfMenu - the menu
#            xfX - the root x coordinate
#            xfY - the root x coordinate
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  if {"[info commands $xfMenu]" != ""} {
    if {![info exists tk_popupPriv($xfMenu,focus)]} {
      set tk_popupPriv($xfMenu,focus) [focus]
    } {
      if {"$tk_popupPriv($xfMenu,focus)" == ""} {
        set tk_popupPriv($xfMenu,focus) [focus]
      }
    }
    set tk_popupPriv($xfMenu,grab) $xfMenu

    catch "$xfMenu activate none"
    catch "$xfMenu post $xfX $xfY"
    catch "focus $xfMenu"
    catch "grab -global $xfMenu"
  }
}
}


# Procedure: MenuPopupRelease
if {"[info procs MenuPopupRelease]" == ""} {
proc MenuPopupRelease { xfMenu xfW} {
# xf ignore me 7
##########
# Procedure: MenuPopupRelease
# Description: remove the popup menu
# Arguments: xfMenu - the topmost menu widget
#            xfW - the menu widget
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv
  global tkVersion

  if {"[info commands $xfW]" != "" && [winfo ismapped $xfW] &&
      "[winfo class $xfW]" == "Menu" &&
      [info exists tk_popupPriv($xfMenu,focus)] &&
      "$tk_popupPriv($xfMenu,focus)" != "" &&
      [info exists tk_popupPriv($xfMenu,grab)] &&
      "$tk_popupPriv($xfMenu,grab)" != ""} {
    if {$tkVersion >= 3.0} {
      catch "grab release $tk_popupPriv($xfMenu,grab)"
    } {
      catch "grab none"
    }
    catch "focus $tk_popupPriv($xfMenu,focus)"
    set tk_popupPriv($xfMenu,focus) ""
    set tk_popupPriv($xfMenu,grab) ""
    if {"[$xfW index active]" != "none"} {
      $xfW invoke active; catch "$xfMenu unpost"
    }
  }
  catch "$xfMenu unpost"
}
}


# Procedure: NoFunction
if {"[info procs NoFunction]" == ""} {
proc NoFunction { args} {
# xf ignore me 7
##########
# Procedure: NoFunction
# Description: do nothing
# Arguments: args - any kind of arguments
# Returns: none
# Sideeffects: none
##########
}
}


# Procedure: SN
if {"[info procs SN]" == ""} {
proc SN { {xfName ""}} {
# xf ignore me 7
##########
# Procedure: SN
# Description: map a symbolic name to the widget path
# Arguments: xfName
# Returns: the symbolic name
# Sideeffects: none
##########

  SymbolicName $xfName
}
}


# Procedure: SymbolicName
if {"[info procs SymbolicName]" == ""} {
proc SymbolicName { {xfName ""}} {
# xf ignore me 7
##########
# Procedure: SymbolicName
# Description: map a symbolic name to the widget path
# Arguments: xfName
# Returns: the symbolic name
# Sideeffects: none
##########

  global symbolicName

  if {"$xfName" != ""} {
    set xfArrayName ""
    append xfArrayName symbolicName ( $xfName )
    if {![catch "set \"$xfArrayName\"" xfValue]} {
      return $xfValue
    } {
      if {"[info commands XFProcError]" != ""} {
        XFProcError "Unknown symbolic name:\n$xfName"
      } {
        puts stderr "XF error: unknown symbolic name:\n$xfName"
      }
    }
  }
  return ""
}
}


# Procedure: Unalias
if {"[info procs Unalias]" == ""} {
proc Unalias { aliasName} {
# xf ignore me 7
##########
# Procedure: Unalias
# Description: remove an alias for a procedure
# Arguments: aliasName - the alias name to remove
# Returns: none
# Sideeffects: internalAliasList is updated, and the alias
#              proc is removed
##########
  global internalAliasList

  set xfIndex [lsearch $internalAliasList "$aliasName *"]
  if {$xfIndex != -1} {
    rename $aliasName ""
    set internalAliasList [lreplace $internalAliasList $xfIndex $xfIndex]
  }
}
}



# application parsing procedure
proc XFLocalParseAppDefs {xfAppDefFile} {
  global xfAppDefaults

  # basically from: Michael Moore
  if {[file exists $xfAppDefFile] &&
      [file readable $xfAppDefFile] &&
      "[file type $xfAppDefFile]" == "link"} {
    catch "file type $xfAppDefFile" xfType
    while {"$xfType" == "link"} {
      if {[catch "file readlink $xfAppDefFile" xfAppDefFile]} {
        return
      }
      catch "file type $xfAppDefFile" xfType
    }
  }
  if {!("$xfAppDefFile" != "" &&
        [file exists $xfAppDefFile] &&
        [file readable $xfAppDefFile] &&
        "[file type $xfAppDefFile]" == "file")} {
    return
  }
  if {![catch "open $xfAppDefFile r" xfResult]} {
    set xfAppFileContents [read $xfResult]
    close $xfResult
    foreach line [split $xfAppFileContents "\n"] {
      # backup indicates how far to backup.  It applies to the
      # situation where a resource name ends in . and when it
      # ends in *.  In the second case you want to keep the *
      # in the widget name for pattern matching, but you want
      # to get rid of the . if it is the end of the name. 
      set backup -2  
      set line [string trim $line]
      if {[string index $line 0] == "#" || "$line" == ""} {
        # skip comments and empty lines
        continue
      }
      set list [split $line ":"]
      set resource [string trim [lindex $list 0]]
      set i [string last "." $resource]
      set j [string last "*" $resource]
      if {$j > $i} { 
        set i $j
        set backup -1
      }
      incr i
      set name [string range $resource $i end]
      incr i $backup
      set widname [string range $resource 0 $i]
      set value [string trim [lindex $list 1]]
      if {"$widname" != "" && "$widname" != "*"} {
        # insert the widget and resourcename to the application
        # defaults list.
        if {![info exists xfAppDefaults]} {
          set xfAppDefaults ""
        }
        lappend xfAppDefaults [list $widname [string tolower $name] $value]
      }
    }
  }
}

# application loading procedure
proc XFLocalLoadAppDefs {{xfClasses ""} {xfPriority "startupFile"} {xfAppDefFile ""}} {
  global env

  if {"$xfAppDefFile" == ""} {
    set xfFileList ""
    if {[info exists env(XUSERFILESEARCHPATH)]} {
      append xfFileList [split $env(XUSERFILESEARCHPATH) :]
    }
    if {[info exists env(XAPPLRESDIR)]} {
      append xfFileList [split $env(XAPPLRESDIR) :]
    }
    if {[info exists env(XFILESEARCHPATH)]} {
      append xfFileList [split $env(XFILESEARCHPATH) :]
    }
    append xfFileList " /usr/lib/X11/app-defaults"
    append xfFileList " /usr/X11/lib/X11/app-defaults"

    foreach xfCounter1 $xfClasses {
      foreach xfCounter2 $xfFileList {
        set xfPathName $xfCounter2
        if {[regsub -all "%N" "$xfPathName" "$xfCounter1" xfResult]} {
          set xfPathName $xfResult
        }
        if {[regsub -all "%T" "$xfPathName" "app-defaults" xfResult]} {
          set xfPathName $xfResult
        }
        if {[regsub -all "%S" "$xfPathName" "" xfResult]} {
          set xfPathName $xfResult
        }
        if {[regsub -all "%C" "$xfPathName" "" xfResult]} {
          set xfPathName $xfResult
        }
        if {[file exists $xfPathName] &&
            [file readable $xfPathName] &&
            ("[file type $xfPathName]" == "file" ||
             "[file type $xfPathName]" == "link")} {
          catch "option readfile $xfPathName $xfPriority"
          if {"[info commands XFParseAppDefs]" != ""} {
            XFParseAppDefs $xfPathName
          } {
            if {"[info commands XFLocalParseAppDefs]" != ""} {
              XFLocalParseAppDefs $xfPathName
            }
          }
        } {
          if {[file exists $xfCounter2/$xfCounter1] &&
              [file readable $xfCounter2/$xfCounter1] &&
              ("[file type $xfCounter2/$xfCounter1]" == "file" ||
               "[file type $xfCounter2/$xfCounter1]" == "link")} {
            catch "option readfile $xfCounter2/$xfCounter1 $xfPriority"
            if {"[info commands XFParseAppDefs]" != ""} {
              XFParseAppDefs $xfCounter2/$xfCounter1
            } {
              if {"[info commands XFLocalParseAppDefs]" != ""} {
                XFLocalParseAppDefs $xfCounter2/$xfCounter1
              }
            }
          }
        }
      }
    }
  } {
    # load a specific application defaults file
    if {[file exists $xfAppDefFile] &&
        [file readable $xfAppDefFile] &&
        ("[file type $xfAppDefFile]" == "file" ||
         "[file type $xfAppDefFile]" == "link")} {
      catch "option readfile $xfAppDefFile $xfPriority"
      if {"[info commands XFParseAppDefs]" != ""} {
        XFParseAppDefs $xfAppDefFile
      } {
        if {"[info commands XFLocalParseAppDefs]" != ""} {
          XFLocalParseAppDefs $xfAppDefFile
        }
      }
    }
  }
}

# application setting procedure
proc XFLocalSetAppDefs {{xfWidgetPath "."}} {
  global xfAppDefaults

  if {![info exists xfAppDefaults]} {
    return
  }
  foreach xfCounter $xfAppDefaults {
    if {"$xfCounter" == ""} {
      break
    }
    set widname [lindex $xfCounter 0]
    if {[string match $widname ${xfWidgetPath}] ||
        [string match "${xfWidgetPath}*" $widname]} {
      set name [string tolower [lindex $xfCounter 1]]
      set value [lindex $xfCounter 2]
      # Now lets see how many tcl commands match the name
      # pattern specified.
      set widlist [info command $widname]
      if {"$widlist" != ""} {
        foreach widget $widlist {
          # make sure this command is a widget.
          if {![catch "winfo id $widget"] &&
              [string match "${xfWidgetPath}*" $widget]} {
            catch "$widget configure -$name $value" 
          }
        }
      }
    }
  }
}



# startup source
proc StartupSrc {args} {

}


# end source
proc EndSrc {} {
global argc argv argv0
global nameServerPort
set nameServerPort 8765
global traceName
set traceName "NS.log.LDIB"

for {set counter 0} {$counter < $argc} {incr counter 1} {
  case [string tolower [lindex $argv $counter]] in {
    {"-tracefile" "-tf"} {
      incr counter 1
      set traceName "[lindex $argv $counter]" 	
    }
    {"-nameserverport" "-nsp"} {
      incr counter 1
      set nameServerPort "[lindex $argv $counter]" 	
    }
    {default} {
      puts "SYNOPSIS : $argv0"
      puts {           [-nameserverport <int>] [-tracefile <filename>]}
      exit
    }
  }
}

installServer
}

# prepare auto loading
global auto_path
global tk_library
global xfLoadPath
foreach xfElement [eval list [split $xfLoadPath :] $auto_path] {
  if {[file exists $xfElement/tclIndex]} {
    lappend auto_path $xfElement
  }
}
catch "unset auto_index"
catch "unset auto_oldpath"
catch "unset auto_execs"

XFLocalIncludeModule database
XFLocalIncludeModule file
XFLocalIncludeModule NameServer.procs
XFLocalIncludeModule NameServer.rpc
XFLocalIncludeModule Copyright

# startup source
StartupSrc

# initialize global variables
proc InitGlobals {} {
  global {checkIntervall}
  set {checkIntervall} {600}
  global {imageServerPort}
  set {imageServerPort} {8766}
  global {nameOfMine}
  set {nameOfMine} {label5}
  global {nameOfServer}
  set {nameServerPort} {8765}
  global {statusWord}
  set {statusWord} {}
  global {traceName}
  set {traceName} {}

  # please don't modify the following
  # variables. They are needed by xf.
  global {autoLoadList}
  set {autoLoadList(NameServer4.tcl)} {0}
  global {internalAliasList}
  set {internalAliasList} {{ServerListbox .frame3.frame.listbox1} {ServerListboxTitle .frame3.frame.listbox0}}
  global {moduleList}
  set {moduleList(NameServer4.tcl)} {}
  global {preloadList}
  set {preloadList(xfInternal)} {}
  global {symbolicName}
  set {symbolicName(root)} {.}
  global {xfWmSetPosition}
  set {xfWmSetPosition} {}
  global {xfWmSetSize}
  set {xfWmSetSize} {.}
  global {xfAppDefToplevels}
  set {xfAppDefToplevels} {}
}

# initialize global variables
InitGlobals

# display/remove toplevel windows.
ShowWindow.

# load default bindings.
if {[info exists env(XF_BIND_FILE)] &&
    "[info procs XFShowHelp]" == ""} {
  source $env(XF_BIND_FILE)
}

# parse and apply application defaults.
XFLocalLoadAppDefs NameServer4
XFLocalSetAppDefs

# end source
EndSrc

# eof
#

