#!/usr/local/bin/dpwish -f
# Program: main
# Tcl version: 7.3 (Tcl/Tk/XF)
# Tk version: 3.6
# XF version: 2.2
#


#/*
# * RetrievingTool.tcl - Retrieving Tool of the LOSSLESS DIGITAL IMAGE BROWSER
# *
# *  Author:    Rainer Lienhart, University of Mannheim, Germany
# *             (lienhart@pi4.informatik.uni-mannheim.de) or
# *             ICSI - International Computer Science Institue
# *             (lienhart@icsi.berkeley.edu)
# */

#/* Copyright Notice
# * ================
# * Copyright 1994 by Rainer Lienhart
# * 
# * Permission to use, copy, and distribute LDIB in its entirety, for 
# * non-commercial purposes, is hereby granted without fee, provided that
# * this license information and copyright notice appear in all copies.
# * 
# * Note that distributing LDIB 'bundled' in with ANY product is considered
# * to be a 'commercial purpose'.
# *
# * The software may be modified for your own purposes, but modified
# * versions may NOT be distributed without prior consent of the author.
# * 
# * This software is provided 'as-is', without any express or implied
# * warranty.  In no event will the author be held liable for any damages
# * arising from the use of this software.
# * 
# * If you would like to do something with LDIB that this copyright
# * prohibits (such as distributing it with a commercial product), please
# * contact the author (preferably via email).  Arrangements can
# * probably be worked out.
# *
# * The author may be contacted via:
# *    Mail:     Rainer Lienhart
# *              Universitaet Mannheim
# *              Praktische Informatik IV
# *              68131 Mannheim
# *              Germany
# *
# *    Phone:    phone  : +49 621 292 1407
# *              fax    : +49 621 292 5745
# *    EMail:    lienhart@pi4.informatik.uni-mannheim.de
# */


if {[info exists env(LDIB_PATH)] == 0} {
  puts "---------------------------------------------------"
  puts "ERROR: Need environment variable LDIB_PATH"
  puts "Please set LDIB_PATH to the root directory of the LDIB"
  puts "For instance, by \"setenv LDIB_PATH <pathname>\""
  exit
}
global LDIB
set LDIB $env(LDIB_PATH)

# module inclusion
global env
global xfLoadPath
global xfLoadInfo
set xfLoadInfo 0
if {[info exists env(LDIB_PATH)]} {
  if {[string first $env(LDIB_PATH) ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/] == -1} {
    set xfLoadPath $env(LDIB_PATH):${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
  } {
    set xfLoadPath ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
  }
} {
  set xfLoadPath ${LDIB}/tk-scripts:${LDIB}/procedures:/usr/local/lib/
}

global argc
global argv
global tkVersion
set tmpArgv ""
for {set counter 0} {$counter < $argc} {incr counter 1} {
  case [string tolower [lindex $argv $counter]] in {
    {-xfloadpath} {
      incr counter 1
      set xfLoadPath "[lindex $argv $counter]:$xfLoadPath"
    }
    {-xfstartup} {
      incr counter 1
      source [lindex $argv $counter]
    }
    {-xfbindfile} {
      incr counter 1
      set env(XF_BIND_FILE) "[lindex $argv $counter]"
    }
    {-xfcolorfile} {
      incr counter 1
      set env(XF_COLOR_FILE) "[lindex $argv $counter]"
    }
    {-xfcursorfile} {
      incr counter 1
      set env(XF_CURSOR_FILE) "[lindex $argv $counter]"
    }
    {-xffontfile} {
      incr counter 1
      set env(XF_FONT_FILE) "[lindex $argv $counter]"
    }
    {-xfmodelmono} {
      if {$tkVersion >= 3.0} {
        tk colormodel . monochrome
      }
    }
    {-xfmodelcolor} {
      if {$tkVersion >= 3.0} {
        tk colormodel . color
      }
    }
    {-xfloading} {
      set xfLoadInfo 1
    }
    {-xfnoloading} {
      set xfLoadInfo 0
    }
    {default} {
      lappend tmpArgv [lindex $argv $counter]
    }
  }
}
set argv $tmpArgv
set argc [llength $tmpArgv]
unset counter
unset tmpArgv


# procedure to show window .
proc ShowWindow. {args} {# xf ignore me 7
  global LDIB 

  # Window manager configurations
  global tkVersion
  wm positionfrom . ""
  wm sizefrom . ""
  wm geometry . 625x505
  wm iconbitmap . @${LDIB}/bitmaps/Logo.bit
  wm iconname . {LDIB: Retrieving Tool}
  wm maxsize . 1024 768
  wm minsize . 625 505
  wm title . {LDIB: Retrieve Images}


  # build widget .frame3
  frame .frame3 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame3.frame5
  frame .frame3.frame5 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}
  bind .frame3.frame5 <Button-1> { copyrightWindow .copyright }
  bind .frame3.frame5 <Button-2> { copyrightWindow .copyright }
  bind .frame3.frame5 <Button-3> { copyrightWindow .copyright }

  # build widget .frame3.label6
  label .frame3.label6 \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/Logo.bit" \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {label6}
  bind .frame3.label6 <Button-1> { copyrightWindow .copyright }
  bind .frame3.label6 <Button-2> { copyrightWindow .copyright }
  bind .frame3.label6 <Button-3> { copyrightWindow .copyright }

  # build widget .frame3.label7
  label .frame3.label7 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text { LOSSLESS DIGITAL IMAGE BROWSER}
  bind .frame3.label7 <Button-1> { copyrightWindow .copyright }
  bind .frame3.label7 <Button-2> { copyrightWindow .copyright }
  bind .frame3.label7 <Button-3> { copyrightWindow .copyright }

  # build widget .frame3.frame8
  frame .frame3.frame8 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}
  bind .frame3.frame8 <Button-1> { copyrightWindow .copyright }
  bind .frame3.frame8 <Button-2> { copyrightWindow .copyright }
  bind .frame3.frame8 <Button-3> { copyrightWindow .copyright }

  # pack widget .frame3
  pack append .frame3 \
    .frame3.frame5 {left frame center expand fillx} \
    .frame3.label6 {left frame center} \
    .frame3.label7 {left frame center} \
    .frame3.frame8 {left frame center expand fillx}

  # build widget .frame0
  frame .frame0 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame0.frame0
  frame .frame0.frame0 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame0.frame0.label3
  label .frame0.frame0.label3 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {Name Server Address:}

  # build widget .frame0.frame0.entry4
  entry .frame0.frame0.entry4 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -insertborderwidth {1} \
    -relief {sunken} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -textvariable {nameOfNameServer}

  # build widget .frame0.frame0.entry5
  entry .frame0.frame0.entry5 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -insertborderwidth {1} \
    -relief {sunken} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -textvariable {nameServerPort}

  # build widget .frame0.frame0.label6
  label .frame0.frame0.label6 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {  Name Server Portnumber:}

  # pack widget .frame0.frame0
  pack append .frame0.frame0 \
    .frame0.frame0.label3 {left frame center} \
    .frame0.frame0.entry4 {left frame center padx 10 expand fillx} \
    .frame0.frame0.entry5 {right frame center padx 10 expand fillx} \
    .frame0.frame0.label6 {right frame center}

  # build widget .frame0.frame1
  frame .frame0.frame1 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame0.frame1.label3
  label .frame0.frame1.label3 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {Message:}

  # build widget .frame0.frame1.message4
  message .frame0.frame1.message4 \
    -aspect {1500} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -padx {5} \
    -pady {2} \
    -text {message4} \
    -textvariable {statusWord}

  # pack widget .frame0.frame1
  pack append .frame0.frame1 \
    .frame0.frame1.label3 {left frame center} \
    .frame0.frame1.message4 {left frame center expand fillx}

  # pack widget .frame0
  pack append .frame0 \
    .frame0.frame0 {top frame center fillx} \
    .frame0.frame1 {top frame center fillx}

  # build widget .frame15
  frame .frame15 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame15.frame10
  frame .frame15.frame10 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame10.label12
  label .frame15.frame10.label12 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {Find Expression: }

  # build widget .frame15.frame10.entry13
  entry .frame15.frame10.entry13 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -insertborderwidth {1} \
    -relief {sunken} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -textvariable {findPattern}
  # bindings
  bind .frame15.frame10.entry13 <Key-Return> {
     doFind
  }

  # pack widget .frame15.frame10
  pack append .frame15.frame10 \
    .frame15.frame10.label12 {left frame center} \
    .frame15.frame10.entry13 {left frame center expand fillx}

  # build widget .frame15.frame11
  frame .frame15.frame11 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame11.button14
  button .frame15.frame11.button14 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/find.bit" \
    -borderwidth {1} \
    -command {doFind} \
    -font {6x13} \
    -foreground {#000000} \
    -text {button14}

  # pack widget .frame15.frame11
  pack append .frame15.frame11 \
    .frame15.frame11.button14 {top frame center}

  # build widget .frame15.frame21
  frame .frame15.frame21 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame16
  frame .frame15.frame21.frame16 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame15.frame21.frame16.frame3
  frame .frame15.frame21.frame16.frame3 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame16.frame3.label1
  label .frame15.frame21.frame16.frame3.label1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {Image Servers:}

  # build widget .frame15.frame21.frame16.frame3.frame
  frame .frame15.frame21.frame16.frame3.frame \
    -background {#f0f0f0} \
    -borderwidth {1}

  # build widget .frame15.frame21.frame16.frame3.frame.scrollbar3
  scrollbar .frame15.frame21.frame16.frame3.frame.scrollbar3 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame16.frame3.frame.listbox1 xview} \
    -foreground {#b0b0b0} \
    -orient {horizontal} \
    -relief {raised} \
    -width {12}

  # build widget .frame15.frame21.frame16.frame3.frame.scrollbar2
  scrollbar .frame15.frame21.frame16.frame3.frame.scrollbar2 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame16.frame3.frame.listbox1 yview} \
    -foreground {#b0b0b0} \
    -relief {raised} \
    -width {12}

  # build widget .frame15.frame21.frame16.frame3.frame.listbox1
  listbox .frame15.frame21.frame16.frame3.frame.listbox1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -relief {raised} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -xscrollcommand {.frame15.frame21.frame16.frame3.frame.scrollbar3 set} \
    -yscrollcommand {.frame15.frame21.frame16.frame3.frame.scrollbar2 set}
  # bindings
  bind .frame15.frame21.frame16.frame3.frame.listbox1 <Button-2> {
     get&show_ISList
  }
  bind .frame15.frame21.frame16.frame3.frame.listbox1 <Double-Button-1> { 
    # new Image Server chosen
    global actdir NameOfImageserver imageServerPort
    set actdir ""

    set selectedIndices [.frame15.frame21.frame16.frame3.frame.listbox1 curselection]
    set entry [split [.frame15.frame21.frame16.frame3.frame.listbox1 get $selectedIndices] ": "]
    global NameOfImageserver imageServerPort
    set NameOfImageserver [lindex $entry 0]
    set imageServerPort [lindex $entry 2]
    filebrowse .frame15.frame21.frame17.frame4.frame.listbox1 "/"
  }

  # pack widget .frame15.frame21.frame16.frame3.frame
  pack append .frame15.frame21.frame16.frame3.frame \
    .frame15.frame21.frame16.frame3.frame.scrollbar2 {right frame center filly} \
    .frame15.frame21.frame16.frame3.frame.listbox1 {top frame center expand fill} \
    .frame15.frame21.frame16.frame3.frame.scrollbar3 {bottom frame center fillx}

  # pack widget .frame15.frame21.frame16.frame3
  pack append .frame15.frame21.frame16.frame3 \
    .frame15.frame21.frame16.frame3.label1 {top frame center fill} \
    .frame15.frame21.frame16.frame3.frame {top frame center expand fill}

  # build widget .frame15.frame21.frame16.frame9
  frame .frame15.frame21.frame16.frame9 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame16.frame9.frame0
  frame .frame15.frame21.frame16.frame9.frame0 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame16.frame9.frame0.label3
  label .frame15.frame21.frame16.frame9.frame0.label3 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {Select:}

  # build widget .frame15.frame21.frame16.frame9.frame0.button4
  button .frame15.frame21.frame16.frame9.frame0.button4 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {global is.listbox; list.selectAll ${is.listbox}} \
    -font {6x13} \
    -foreground {#000000} \
    -text {ALL}

  # build widget .frame15.frame21.frame16.frame9.frame0.button5
  button .frame15.frame21.frame16.frame9.frame0.button5 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {global is.listbox; list.selectNone ${is.listbox}} \
    -font {6x13} \
    -foreground {#000000} \
    -text {NONE}

  # pack widget .frame15.frame21.frame16.frame9.frame0
  pack append .frame15.frame21.frame16.frame9.frame0 \
    .frame15.frame21.frame16.frame9.frame0.label3 {left frame center} \
    .frame15.frame21.frame16.frame9.frame0.button4 {left frame center expand fillx} \
    .frame15.frame21.frame16.frame9.frame0.button5 {left frame center expand fillx}

  # build widget .frame15.frame21.frame16.frame9.frame1
  frame .frame15.frame21.frame16.frame9.frame1 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame16.frame9.frame1.frame
  frame .frame15.frame21.frame16.frame9.frame1.frame \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame16.frame9.frame1.frame.frame
  frame .frame15.frame21.frame16.frame9.frame1.frame.frame \
    -background {#f0f0f0} \
    -borderwidth {1}

  # build widget .frame15.frame21.frame16.frame9.frame1.frame.frame.scrollbar1
  scrollbar .frame15.frame21.frame16.frame9.frame1.frame.frame.scrollbar1 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame16.frame9.frame1.frame.frame.entry2 view} \
    -foreground {#b0b0b0} \
    -orient {horizontal} \
    -width {11}

  # build widget .frame15.frame21.frame16.frame9.frame1.frame.frame.entry2
  entry .frame15.frame21.frame16.frame9.frame1.frame.frame.entry2 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -insertborderwidth {1} \
    -relief {sunken} \
    -scrollcommand {.frame15.frame21.frame16.frame9.frame1.frame.frame.scrollbar1 set} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
     -textvariable {.frame15.frame21.frame16.frame3.frame.listbox1pattern}
  # bindings
  bind .frame15.frame21.frame16.frame9.frame1.frame.frame.entry2 <Key-Return> { global is.listbox is.mode; list.doSelection ${is.listbox} ${is.mode}}

  # pack widget .frame15.frame21.frame16.frame9.frame1.frame.frame
  pack append .frame15.frame21.frame16.frame9.frame1.frame.frame \
    .frame15.frame21.frame16.frame9.frame1.frame.frame.entry2 {top frame center expand fill} \
    .frame15.frame21.frame16.frame9.frame1.frame.frame.scrollbar1 {top frame center fillx}

  # build widget .frame15.frame21.frame16.frame9.frame1.frame.label1
  label .frame15.frame21.frame16.frame9.frame1.frame.label1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {Pattern:}

  # pack widget .frame15.frame21.frame16.frame9.frame1.frame
  pack append .frame15.frame21.frame16.frame9.frame1.frame \
    .frame15.frame21.frame16.frame9.frame1.frame.label1 {left frame center filly} \
    .frame15.frame21.frame16.frame9.frame1.frame.frame {top frame center fillx}

  # pack widget .frame15.frame21.frame16.frame9.frame1
  pack append .frame15.frame21.frame16.frame9.frame1 \
    .frame15.frame21.frame16.frame9.frame1.frame {top frame center expand fill}

  # build widget .frame15.frame21.frame16.frame9.frame2
  frame .frame15.frame21.frame16.frame9.frame2 \
    -background {#f0f0f0} \
    -borderwidth {2}
  # bindings
  bind .frame15.frame21.frame16.frame9.frame2 <Any-ButtonRelease-1> {MenuPopupRelease .frame15.frame21.frame16.frame9.frame2.menu0 %W}
  bind .frame15.frame21.frame16.frame9.frame2 <Button-1> {MenuPopupPost .frame15.frame21.frame16.frame9.frame2.menu8 %X %Y}
  bind .frame15.frame21.frame16.frame9.frame2 <Button-2> {MenuPopupPost .frame15.frame21.frame16.frame9.frame2.menu9 %X %Y}
  bind .frame15.frame21.frame16.frame9.frame2 <ButtonRelease-1> {MenuPopupRelease .frame15.frame21.frame16.frame9.frame2.menu8 %W}
  bind .frame15.frame21.frame16.frame9.frame2 <ButtonRelease-2> {MenuPopupRelease .frame15.frame21.frame16.frame9.frame2.menu9 %W}
  bind .frame15.frame21.frame16.frame9.frame2 <Shift-Button-1> {MenuPopupPost .frame15.frame21.frame16.frame9.frame2.menu0 %X %Y}

  # build widget .frame15.frame21.frame16.frame9.frame2.frame0
  frame .frame15.frame21.frame16.frame9.frame2.frame0 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame16.frame9.frame2.frame0.label1
  label .frame15.frame21.frame16.frame9.frame2.frame0.label1 \
    -background {#f0f0f0} \
    -borderwidth {0} \
    -font {6x13} \
    -foreground {#000000} \
    -text {with  }

  # build widget .frame15.frame21.frame16.frame9.frame2.frame0.menubutton2
  menubutton .frame15.frame21.frame16.frame9.frame2.frame0.menubutton2 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -menu {.frame15.frame21.frame16.frame9.frame2.frame0.menubutton2.m} \
    -relief {raised} \
    -text {glob style} \
    -textvariable {.frame15.frame21.frame16.frame3.frame.listbox1patterntype}

  # build widget .frame15.frame21.frame16.frame9.frame2.frame0.menubutton2.m
  menu .frame15.frame21.frame16.frame9.frame2.frame0.menubutton2.m \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000}
  .frame15.frame21.frame16.frame9.frame2.frame0.menubutton2.m add command \
    -command {set .frame15.frame21.frame16.frame3.frame.listbox1patterntype "glob style"} \
    -label {glob style} \
    -state {active}
  .frame15.frame21.frame16.frame9.frame2.frame0.menubutton2.m add command \
    -command {set .frame15.frame21.frame16.frame3.frame.listbox1patterntype "regular expr"} \
    -label {regular expr}

  # pack widget .frame15.frame21.frame16.frame9.frame2.frame0
  pack append .frame15.frame21.frame16.frame9.frame2.frame0 \
    .frame15.frame21.frame16.frame9.frame2.frame0.label1 {left frame center fill} \
    .frame15.frame21.frame16.frame9.frame2.frame0.menubutton2 {left frame center expand fillx}

  # pack widget .frame15.frame21.frame16.frame9.frame2
  pack append .frame15.frame21.frame16.frame9.frame2 \
    .frame15.frame21.frame16.frame9.frame2.frame0 {top frame center expand fillx}

  # pack widget .frame15.frame21.frame16.frame9
  pack append .frame15.frame21.frame16.frame9 \
    .frame15.frame21.frame16.frame9.frame0 {top frame center fillx} \
    .frame15.frame21.frame16.frame9.frame1 {top frame center fillx} \
    .frame15.frame21.frame16.frame9.frame2 {top frame center fillx}

  # pack widget .frame15.frame21.frame16
  pack append .frame15.frame21.frame16 \
    .frame15.frame21.frame16.frame3 {top frame center expand fill} \
    .frame15.frame21.frame16.frame9 {top frame center fillx}

  # build widget .frame15.frame21.frame17
  frame .frame15.frame21.frame17 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame15.frame21.frame17.frame4
  frame .frame15.frame21.frame17.frame4 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame17.frame4.label0
  label .frame15.frame21.frame17.frame4.label0 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -text {Image Directory:}

  # build widget .frame15.frame21.frame17.frame4.frame
  frame .frame15.frame21.frame17.frame4.frame \
    -background {#f0f0f0} \
    -borderwidth {1}

  # build widget .frame15.frame21.frame17.frame4.frame.scrollbar3
  scrollbar .frame15.frame21.frame17.frame4.frame.scrollbar3 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame17.frame4.frame.listbox1 xview} \
    -foreground {#b0b0b0} \
    -orient {horizontal} \
    -relief {raised} \
    -width {12}

  # build widget .frame15.frame21.frame17.frame4.frame.scrollbar2
  scrollbar .frame15.frame21.frame17.frame4.frame.scrollbar2 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame17.frame4.frame.listbox1 yview} \
    -foreground {#b0b0b0} \
    -relief {raised} \
    -width {12}

  # build widget .frame15.frame21.frame17.frame4.frame.listbox1
  listbox .frame15.frame21.frame17.frame4.frame.listbox1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -relief {raised} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -xscrollcommand {.frame15.frame21.frame17.frame4.frame.scrollbar3 set} \
    -yscrollcommand {.frame15.frame21.frame17.frame4.frame.scrollbar2 set}
  # bindings
  bind .frame15.frame21.frame17.frame4.frame.listbox1 <Button-2> {
    global from.listbox from.mode
    if {${from.mode} == "short"} {
      set from.mode "long"
    } else {
      set from.mode "short"
    }
    list.doSelection ${from.listbox} ${from.mode}
  }
  bind .frame15.frame21.frame17.frame4.frame.listbox1 <Double-Button-1> {
    global from.listbox

    set entryNo [${from.listbox} curselection]
    global from.mode
    set entry [list.findEntry ${from.listbox} $entryNo ${from.mode}]
    filebrowse .frame15.frame21.frame17.frame4.frame.listbox1 $entry
  }

  # pack widget .frame15.frame21.frame17.frame4.frame
  pack append .frame15.frame21.frame17.frame4.frame \
    .frame15.frame21.frame17.frame4.frame.scrollbar2 {right frame center filly} \
    .frame15.frame21.frame17.frame4.frame.listbox1 {top frame center expand fill} \
    .frame15.frame21.frame17.frame4.frame.scrollbar3 {bottom frame center fillx}

  # pack widget .frame15.frame21.frame17.frame4
  pack append .frame15.frame21.frame17.frame4 \
    .frame15.frame21.frame17.frame4.label0 {top frame center fill} \
    .frame15.frame21.frame17.frame4.frame {top frame center expand fill}

  # build widget .frame15.frame21.frame17.frame10
  frame .frame15.frame21.frame17.frame10 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame17.frame10.frame0
  frame .frame15.frame21.frame17.frame10.frame0 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame17.frame10.frame0.label3
  label .frame15.frame21.frame17.frame10.frame0.label3 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {Select:}

  # build widget .frame15.frame21.frame17.frame10.frame0.button4
  button .frame15.frame21.frame17.frame10.frame0.button4 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {global from.listbox; list.selectAll ${from.listbox}} \
    -font {6x13} \
    -foreground {#000000} \
    -text {ALL}

  # build widget .frame15.frame21.frame17.frame10.frame0.button0
  button .frame15.frame21.frame17.frame10.frame0.button0 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {global from.listbox; list.selectNone ${from.listbox}} \
    -font {6x13} \
    -foreground {#000000} \
    -text {NONE}

  # pack widget .frame15.frame21.frame17.frame10.frame0
  pack append .frame15.frame21.frame17.frame10.frame0 \
    .frame15.frame21.frame17.frame10.frame0.label3 {left frame center} \
    .frame15.frame21.frame17.frame10.frame0.button4 {left frame center expand fillx} \
    .frame15.frame21.frame17.frame10.frame0.button0 {left frame center expand fillx}

  # build widget .frame15.frame21.frame17.frame10.frame1
  frame .frame15.frame21.frame17.frame10.frame1 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame17.frame10.frame1.frame
  frame .frame15.frame21.frame17.frame10.frame1.frame \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame17.frame10.frame1.frame.frame
  frame .frame15.frame21.frame17.frame10.frame1.frame.frame \
    -background {#f0f0f0} \
    -borderwidth {1}

  # build widget .frame15.frame21.frame17.frame10.frame1.frame.frame.scrollbar1
  scrollbar .frame15.frame21.frame17.frame10.frame1.frame.frame.scrollbar1 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame17.frame10.frame1.frame.frame.entry2 view} \
    -foreground {#b0b0b0} \
    -orient {horizontal} \
    -width {11}

  # build widget .frame15.frame21.frame17.frame10.frame1.frame.frame.entry2
  entry .frame15.frame21.frame17.frame10.frame1.frame.frame.entry2 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -insertborderwidth {1} \
    -relief {sunken} \
    -scrollcommand {.frame15.frame21.frame17.frame10.frame1.frame.frame.scrollbar1 set} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -textvariable {.frame15.frame21.frame17.frame4.frame.listbox1pattern}
  # bindings
  bind .frame15.frame21.frame17.frame10.frame1.frame.frame.entry2 <Key-Return> { global from.listbox from.mode
    list.doSelection ${from.listbox} ${from.mode}
  }

  # pack widget .frame15.frame21.frame17.frame10.frame1.frame.frame
  pack append .frame15.frame21.frame17.frame10.frame1.frame.frame \
    .frame15.frame21.frame17.frame10.frame1.frame.frame.entry2 {top frame center expand fill} \
    .frame15.frame21.frame17.frame10.frame1.frame.frame.scrollbar1 {top frame center fillx}

  # build widget .frame15.frame21.frame17.frame10.frame1.frame.label1
  label .frame15.frame21.frame17.frame10.frame1.frame.label1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {Pattern:}

  # pack widget .frame15.frame21.frame17.frame10.frame1.frame
  pack append .frame15.frame21.frame17.frame10.frame1.frame \
    .frame15.frame21.frame17.frame10.frame1.frame.label1 {left frame center filly} \
    .frame15.frame21.frame17.frame10.frame1.frame.frame {top frame center fillx}

  # pack widget .frame15.frame21.frame17.frame10.frame1
  pack append .frame15.frame21.frame17.frame10.frame1 \
    .frame15.frame21.frame17.frame10.frame1.frame {top frame center expand fill}

  # build widget .frame15.frame21.frame17.frame10.frame2
  frame .frame15.frame21.frame17.frame10.frame2 \
    -background {#f0f0f0} \
    -borderwidth {2}
  # bindings
  bind .frame15.frame21.frame17.frame10.frame2 <Any-ButtonRelease-1> {MenuPopupRelease .frame15.frame21.frame17.frame10.frame2.menu0 %W}
  bind .frame15.frame21.frame17.frame10.frame2 <Button-1> {MenuPopupPost .frame15.frame21.frame17.frame10.frame2.menu8 %X %Y}
  bind .frame15.frame21.frame17.frame10.frame2 <Button-2> {MenuPopupPost .frame15.frame21.frame17.frame10.frame2.menu9 %X %Y}
  bind .frame15.frame21.frame17.frame10.frame2 <ButtonRelease-1> {MenuPopupRelease .frame15.frame21.frame17.frame10.frame2.menu8 %W}
  bind .frame15.frame21.frame17.frame10.frame2 <ButtonRelease-2> {MenuPopupRelease .frame15.frame21.frame17.frame10.frame2.menu9 %W}
  bind .frame15.frame21.frame17.frame10.frame2 <Shift-Button-1> {MenuPopupPost .frame15.frame21.frame17.frame10.frame2.menu0 %X %Y}

  # build widget .frame15.frame21.frame17.frame10.frame2.frame0
  frame .frame15.frame21.frame17.frame10.frame2.frame0 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame17.frame10.frame2.frame0.label1
  label .frame15.frame21.frame17.frame10.frame2.frame0.label1 \
    -background {#f0f0f0} \
    -borderwidth {0} \
    -font {6x13} \
    -foreground {#000000} \
    -text {with  }

  # build widget .frame15.frame21.frame17.frame10.frame2.frame0.menubutton2
  menubutton .frame15.frame21.frame17.frame10.frame2.frame0.menubutton2 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -menu {.frame15.frame21.frame17.frame10.frame2.frame0.menubutton2.m} \
    -relief {raised} \
    -text {glob style} \
    -textvariable {.frame15.frame21.frame17.frame4.frame.listbox1patterntype}

  # build widget .frame15.frame21.frame17.frame10.frame2.frame0.menubutton2.m
  menu .frame15.frame21.frame17.frame10.frame2.frame0.menubutton2.m \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000}
  .frame15.frame21.frame17.frame10.frame2.frame0.menubutton2.m add command \
    -command {set .frame15.frame21.frame17.frame4.frame.listbox1patterntype "glob style"} \
    -label {glob style}
  .frame15.frame21.frame17.frame10.frame2.frame0.menubutton2.m add command \
    -command {set .frame15.frame21.frame17.frame4.frame.listbox1patterntype "regular expr"} \
    -label {regular expr}

  # pack widget .frame15.frame21.frame17.frame10.frame2.frame0
  pack append .frame15.frame21.frame17.frame10.frame2.frame0 \
    .frame15.frame21.frame17.frame10.frame2.frame0.label1 {left frame center fill} \
    .frame15.frame21.frame17.frame10.frame2.frame0.menubutton2 {right frame center expand fillx}

  # pack widget .frame15.frame21.frame17.frame10.frame2
  pack append .frame15.frame21.frame17.frame10.frame2 \
    .frame15.frame21.frame17.frame10.frame2.frame0 {top frame center expand fillx}

  # pack widget .frame15.frame21.frame17.frame10
  pack append .frame15.frame21.frame17.frame10 \
    .frame15.frame21.frame17.frame10.frame0 {top frame center fillx} \
    .frame15.frame21.frame17.frame10.frame1 {top frame center fillx} \
    .frame15.frame21.frame17.frame10.frame2 {top frame center fillx}

  # pack widget .frame15.frame21.frame17
  pack append .frame15.frame21.frame17 \
    .frame15.frame21.frame17.frame4 {top frame center expand fill} \
    .frame15.frame21.frame17.frame10 {top frame center fillx}

  # build widget .frame15.frame21.frame19
  frame .frame15.frame21.frame19 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame19.frame8
  frame .frame15.frame21.frame19.frame8 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame19.frame8.frame18
  frame .frame15.frame21.frame19.frame8.frame18 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}

  # build widget .frame15.frame21.frame19.frame8.button19
  button .frame15.frame21.frame19.frame8.button19 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/PfeilRechts.bit" \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {button19}
  # bindings
  bind .frame15.frame21.frame19.frame8.button19 <Button-1> {AddEntry}

  # build widget .frame15.frame21.frame19.frame8.frame20
  frame .frame15.frame21.frame19.frame8.frame20 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}

  # build widget .frame15.frame21.frame19.frame8.button21
  button .frame15.frame21.frame19.frame8.button21 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -bitmap "@${LDIB}/bitmaps/PfeilLinks.bit" \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {button21}
  # bindings
  bind .frame15.frame21.frame19.frame8.button21 <Button-1> {DelEntry}

  # build widget .frame15.frame21.frame19.frame8.frame22
  frame .frame15.frame21.frame19.frame8.frame22 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}

  # pack widget .frame15.frame21.frame19.frame8
  pack append .frame15.frame21.frame19.frame8 \
    .frame15.frame21.frame19.frame8.frame18 {top frame center expand filly} \
    .frame15.frame21.frame19.frame8.button19 {top frame center} \
    .frame15.frame21.frame19.frame8.frame20 {top frame center expand filly} \
    .frame15.frame21.frame19.frame8.button21 {top frame center} \
    .frame15.frame21.frame19.frame8.frame22 {top frame center expand filly}

  # build widget .frame15.frame21.frame19.frame11
  frame .frame15.frame21.frame19.frame11 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {41x74}

  # pack widget .frame15.frame21.frame19
  pack append .frame15.frame21.frame19 \
    .frame15.frame21.frame19.frame8 {top frame n expand filly} \
    .frame15.frame21.frame19.frame11 {top frame center}

  # build widget .frame15.frame21.frame20
  frame .frame15.frame21.frame20 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame15.frame21.frame20.frame9
  frame .frame15.frame21.frame20.frame9 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame20.frame9.label10
  label .frame15.frame21.frame20.frame9.label10 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -relief {groove} \
    -text {Image Sequence:}

  # build widget .frame15.frame21.frame20.frame9.frame
  frame .frame15.frame21.frame20.frame9.frame \
    -background {#f0f0f0} \
    -borderwidth {1}

  # build widget .frame15.frame21.frame20.frame9.frame.scrollbar3
  scrollbar .frame15.frame21.frame20.frame9.frame.scrollbar3 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame20.frame9.frame.listbox1 xview} \
    -foreground {#b0b0b0} \
    -orient {horizontal} \
    -relief {raised} \
    -width {12}

  # build widget .frame15.frame21.frame20.frame9.frame.scrollbar2
  scrollbar .frame15.frame21.frame20.frame9.frame.scrollbar2 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame20.frame9.frame.listbox1 yview} \
    -foreground {#b0b0b0} \
    -relief {raised} \
    -width {12}

  # build widget .frame15.frame21.frame20.frame9.frame.listbox1
  listbox .frame15.frame21.frame20.frame9.frame.listbox1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -relief {raised} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0} \
    -xscrollcommand {.frame15.frame21.frame20.frame9.frame.scrollbar3 set} \
    -yscrollcommand {.frame15.frame21.frame20.frame9.frame.scrollbar2 set}
  # bindings
  bind .frame15.frame21.frame20.frame9.frame.listbox1 <Button-2> {
    global to.lisbox to.mode
    if {${to.mode} == "short"} {
      set to.mode "long"
    } else {
      set to.mode "short"
    }
    list.doSelection ${to.listbox} ${to.mode}
  }

  # pack widget .frame15.frame21.frame20.frame9.frame
  pack append .frame15.frame21.frame20.frame9.frame \
    .frame15.frame21.frame20.frame9.frame.scrollbar2 {right frame center filly} \
    .frame15.frame21.frame20.frame9.frame.listbox1 {top frame center expand fill} \
    .frame15.frame21.frame20.frame9.frame.scrollbar3 {bottom frame center fillx}

  # pack widget .frame15.frame21.frame20.frame9
  pack append .frame15.frame21.frame20.frame9 \
    .frame15.frame21.frame20.frame9.label10 {top frame center fill} \
    .frame15.frame21.frame20.frame9.frame {top frame center expand fill}

  # build widget .frame15.frame21.frame20.frame12
  frame .frame15.frame21.frame20.frame12 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame20.frame12.frame0
  frame .frame15.frame21.frame20.frame12.frame0 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame20.frame12.frame0.label3
  label .frame15.frame21.frame20.frame12.frame0.label3 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {Select:}

  # build widget .frame15.frame21.frame20.frame12.frame0.button4
  button .frame15.frame21.frame20.frame12.frame0.button4 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {global to.listbox; list.selectAll ${to.listbox}} \
    -font {6x13} \
    -foreground {#000000} \
    -text {ALL}

  # build widget .frame15.frame21.frame20.frame12.frame0.button1
  button .frame15.frame21.frame20.frame12.frame0.button1 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {global to.listbox; list.selectNone ${to.listbox}} \
    -font {6x13} \
    -foreground {#000000} \
    -text {NONE}

  # pack widget .frame15.frame21.frame20.frame12.frame0
  pack append .frame15.frame21.frame20.frame12.frame0 \
    .frame15.frame21.frame20.frame12.frame0.label3 {left frame center} \
    .frame15.frame21.frame20.frame12.frame0.button4 {left frame center expand fillx} \
    .frame15.frame21.frame20.frame12.frame0.button1 {left frame center expand fillx}

  # build widget .frame15.frame21.frame20.frame12.frame1
  frame .frame15.frame21.frame20.frame12.frame1 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame20.frame12.frame1.frame
  frame .frame15.frame21.frame20.frame12.frame1.frame \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame20.frame12.frame1.frame.frame
  frame .frame15.frame21.frame20.frame12.frame1.frame.frame \
    -background {#f0f0f0} \
    -borderwidth {1}

  # build widget .frame15.frame21.frame20.frame12.frame1.frame.frame.scrollbar1
  scrollbar .frame15.frame21.frame20.frame12.frame1.frame.frame.scrollbar1 \
    -activeforeground {#7f7f7f} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {.frame15.frame21.frame20.frame12.frame1.frame.frame.entry2 view} \
    -foreground {#b0b0b0} \
    -orient {horizontal} \
    -width {11}

  # build widget .frame15.frame21.frame20.frame12.frame1.frame.frame.entry2
  entry .frame15.frame21.frame20.frame12.frame1.frame.frame.entry2 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -insertborderwidth {1} \
    -relief {sunken} \
    -scrollcommand {.frame15.frame21.frame20.frame12.frame1.frame.frame.scrollbar1 set} \
    -selectbackground {#7f7f7f} \
    -selectforeground {#f0f0f0}
  # bindings
  bind .frame15.frame21.frame20.frame12.frame1.frame.frame.entry2 <Key-Return> { global to.listbox to.mode
    list.doSelection ${to.listbox} ${to.mode}
  }

  # pack widget .frame15.frame21.frame20.frame12.frame1.frame.frame
  pack append .frame15.frame21.frame20.frame12.frame1.frame.frame \
    .frame15.frame21.frame20.frame12.frame1.frame.frame.entry2 {top frame center expand fill} \
    .frame15.frame21.frame20.frame12.frame1.frame.frame.scrollbar1 {top frame center fillx}

  # build widget .frame15.frame21.frame20.frame12.frame1.frame.label1
  label .frame15.frame21.frame20.frame12.frame1.frame.label1 \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -text {Pattern:}

  # pack widget .frame15.frame21.frame20.frame12.frame1.frame
  pack append .frame15.frame21.frame20.frame12.frame1.frame \
    .frame15.frame21.frame20.frame12.frame1.frame.label1 {left frame center filly} \
    .frame15.frame21.frame20.frame12.frame1.frame.frame {top frame center fillx}

  # pack widget .frame15.frame21.frame20.frame12.frame1
  pack append .frame15.frame21.frame20.frame12.frame1 \
    .frame15.frame21.frame20.frame12.frame1.frame {top frame center expand fill}

  # build widget .frame15.frame21.frame20.frame12.frame2
  frame .frame15.frame21.frame20.frame12.frame2 \
    -background {#f0f0f0} \
    -borderwidth {2}
  # bindings
  bind .frame15.frame21.frame20.frame12.frame2 <Any-ButtonRelease-1> {MenuPopupRelease .frame15.frame21.frame20.frame12.frame2.menu0 %W}
  bind .frame15.frame21.frame20.frame12.frame2 <Button-1> {MenuPopupPost .frame15.frame21.frame20.frame12.frame2.menu8 %X %Y}
  bind .frame15.frame21.frame20.frame12.frame2 <Button-2> {MenuPopupPost .frame15.frame21.frame20.frame12.frame2.menu9 %X %Y}
  bind .frame15.frame21.frame20.frame12.frame2 <ButtonRelease-1> {MenuPopupRelease .frame15.frame21.frame20.frame12.frame2.menu8 %W}
  bind .frame15.frame21.frame20.frame12.frame2 <ButtonRelease-2> {MenuPopupRelease .frame15.frame21.frame20.frame12.frame2.menu9 %W}
  bind .frame15.frame21.frame20.frame12.frame2 <Shift-Button-1> {MenuPopupPost .frame15.frame21.frame20.frame12.frame2.menu0 %X %Y}

  # build widget .frame15.frame21.frame20.frame12.frame2.frame0
  frame .frame15.frame21.frame20.frame12.frame2.frame0 \
    -background {#f0f0f0} \
    -borderwidth {2}

  # build widget .frame15.frame21.frame20.frame12.frame2.frame0.label1
  label .frame15.frame21.frame20.frame12.frame2.frame0.label1 \
    -background {#f0f0f0} \
    -borderwidth {0} \
    -font {6x13} \
    -foreground {#000000} \
    -text {with  }

  # build widget .frame15.frame21.frame20.frame12.frame2.frame0.menubutton2
  menubutton .frame15.frame21.frame20.frame12.frame2.frame0.menubutton2 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000} \
    -menu {.frame15.frame21.frame20.frame12.frame2.frame0.menubutton2.m} \
    -relief {raised} \
    -text {glob style} \
    -textvariable {.frame15.frame21.frame20.frame9.frame.listbox1patterntype}

  # build widget .frame15.frame21.frame20.frame12.frame2.frame0.menubutton2.m
  menu .frame15.frame21.frame20.frame12.frame2.frame0.menubutton2.m \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {6x13} \
    -foreground {#000000}
  .frame15.frame21.frame20.frame12.frame2.frame0.menubutton2.m add command \
    -command {set .frame15.frame21.frame20.frame9.frame.listbox1patterntype "glob style"} \
    -label {glob style}
  .frame15.frame21.frame20.frame12.frame2.frame0.menubutton2.m add command \
    -command {set .frame15.frame21.frame20.frame9.frame.listbox1patterntype "regular expr"} \
    -label {regular expr}

  # pack widget .frame15.frame21.frame20.frame12.frame2.frame0
  pack append .frame15.frame21.frame20.frame12.frame2.frame0 \
    .frame15.frame21.frame20.frame12.frame2.frame0.label1 {left frame center fill} \
    .frame15.frame21.frame20.frame12.frame2.frame0.menubutton2 {right frame center expand fillx}

  # pack widget .frame15.frame21.frame20.frame12.frame2
  pack append .frame15.frame21.frame20.frame12.frame2 \
    .frame15.frame21.frame20.frame12.frame2.frame0 {top frame center expand fillx}

  # pack widget .frame15.frame21.frame20.frame12
  pack append .frame15.frame21.frame20.frame12 \
    .frame15.frame21.frame20.frame12.frame0 {top frame center fillx} \
    .frame15.frame21.frame20.frame12.frame1 {top frame center fillx} \
    .frame15.frame21.frame20.frame12.frame2 {top frame center fillx}

  # pack widget .frame15.frame21.frame20
  pack append .frame15.frame21.frame20 \
    .frame15.frame21.frame20.frame9 {top frame center expand fill} \
    .frame15.frame21.frame20.frame12 {top frame center fillx}

  # pack widget .frame15.frame21
  pack append .frame15.frame21 \
    .frame15.frame21.frame16 {left frame center expand fill} \
    .frame15.frame21.frame17 {left frame center expand fill} \
    .frame15.frame21.frame19 {left frame center filly} \
    .frame15.frame21.frame20 {left frame center expand fill}

  # pack widget .frame15
  pack append .frame15 \
    .frame15.frame10 {top frame center fillx} \
    .frame15.frame11 {top frame center} \
    .frame15.frame21 {top frame center expand fill}

  # build widget .frame2
  frame .frame2 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -relief {groove}

  # build widget .frame2.frame4
  frame .frame2.frame4 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}

  # build widget .frame2.button5
  button .frame2.button5 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {
       global NameOfImageserver imageServerPort to.listbox nameOfMine LDIB
       
       set f1 [open "| ${LDIB}/bin/ImageViewer" r]
       gets $f1 imageViewerPort
       gets $f1 imageViewerPort2

       set sockid [makeRPCClient $NameOfImageserver $imageServerPort]
       set n [${to.listbox} size]
       set imageList ""
       global from.mode
       for {set i 0} {$i<$n} {incr i} {
         set imageList [concat [set imageList] [list.findEntry ${to.listbox} $i ${from.mode}]]
       }
# puts "$imageList"
       catch {dp_RPC $sockid startImageSender $imageList $nameOfMine $imageViewerPort} imageSenderPort
       catch {dp_CloseRPC $sockid}
       exec ${LDIB}/tk-scripts/ControlPanel.tcl -is $NameOfImageserver -isp $imageSenderPort -iv $nameOfMine -ivp $imageViewerPort2 &
 } \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -height {2} \
    -text {PLAY} \
    -width {10}

  # build widget .frame2.frame6
  frame .frame2.frame6 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}

  # build widget .frame2.button9
  button .frame2.button9 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -height {2} \
    -text {HELP } \
    -width {10}

  # build widget .frame2.frame10
  frame .frame2.frame10 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}

  # build widget .frame2.button11
  button .frame2.button11 \
    -activebackground {#7f7f7f} \
    -activeforeground {#f0f0f0} \
    -background {#f0f0f0} \
    -borderwidth {1} \
    -command {terminateRetrievingTool} \
    -font {*-bold-*-*-*-*} \
    -foreground {#000000} \
    -height {2} \
    -text {EXIT} \
    -width {10}

  # build widget .frame2.frame12
  frame .frame2.frame12 \
    -background {#f0f0f0} \
    -borderwidth {2} \
    -geometry {30x30}

  # pack widget .frame2
  pack append .frame2 \
    .frame2.frame4 {left frame center} \
    .frame2.button5 {left frame center pady 10} \
    .frame2.frame6 {left frame center expand fillx} \
    .frame2.button9 {left frame center} \
    .frame2.frame10 {left frame center expand fillx} \
    .frame2.button11 {left frame center} \
    .frame2.frame12 {left frame center}

  # pack widget .
  pack append . \
    .frame3 {top frame center fillx} \
    .frame0 {top frame center fillx} \
    .frame15 {top frame center expand fill} \
    .frame2 {top frame center fillx}

  .frame15.frame21.frame20.frame12.frame1.frame.frame.entry2 insert end {*}



  if {"[info procs XFEdit]" != ""} {
    catch "XFMiscBindWidgetTree ."
    after 2 "catch {XFEditSetShowWindows}"
  }
}


# User defined procedures
# can be found in LDIB/procedures/RetrievingTool.procs
# Internal procedures


# Procedure: Alias
if {"[info procs Alias]" == ""} {
proc Alias { args} {
# xf ignore me 7
##########
# Procedure: Alias
# Description: establish an alias for a procedure
# Arguments: args - no argument means that a list of all aliases
#                   is returned. Otherwise the first parameter is
#                   the alias name, and the second parameter is
#                   the procedure that is aliased.
# Returns: nothing, the command that is bound to the alias or a
#          list of all aliases - command pairs. 
# Sideeffects: internalAliasList is updated, and the alias
#              proc is inserted
##########
  global internalAliasList

  if {[llength $args] == 0} {
    return $internalAliasList
  } {
    if {[llength $args] == 1} {
      set xfTmpIndex [lsearch $internalAliasList "[lindex $args 0] *"]
      if {$xfTmpIndex != -1} {
        return [lindex [lindex $internalAliasList $xfTmpIndex] 1]
      }
    } {
      if {[llength $args] == 2} {
        eval "proc [lindex $args 0] {args} {#xf ignore me 4
return \[eval \"[lindex $args 1] \$args\"\]}"
        set xfTmpIndex [lsearch $internalAliasList "[lindex $args 0] *"]
        if {$xfTmpIndex != -1} {
          set internalAliasList [lreplace $internalAliasList $xfTmpIndex $xfTmpIndex "[lindex $args 0] [lindex $args 1]"]
        } {
          lappend internalAliasList "[lindex $args 0] [lindex $args 1]"
        }
      } {
        error "Alias: wrong number or args: $args"
      }
    }
  }
}
}


# Procedure: GetSelection
if {"[info procs GetSelection]" == ""} {
proc GetSelection {} {
# xf ignore me 7
##########
# Procedure: GetSelection
# Description: get current selection
# Arguments: none
# Returns: none
# Sideeffects: none
##########

  # the save way
  set xfSelection ""
  catch "selection get" xfSelection
  if {"$xfSelection" == "selection doesn't exist or form \"STRING\" not defined"} {
    return ""
  } {
    return $xfSelection
  }
}
}


# Procedure: MenuPopupAdd
if {"[info procs MenuPopupAdd]" == ""} {
proc MenuPopupAdd { xfW xfButton xfMenu {xfModifier ""} {xfCanvasTag ""}} {
# xf ignore me 7
# the popup menu handling is from (I already gave up with popup handling :-):
#
# Copyright 1991,1992 by James Noble.
# Everyone is granted permission to copy, modify and redistribute.
# This notice must be preserved on all copies or derivates.
#
##########
# Procedure: MenuPopupAdd
# Description: attach a popup menu to widget
# Arguments: xfW - the widget
#            xfButton - the button we use
#            xfMenu - the menu to attach
#            {xfModifier} - a optional modifier
#            {xfCanvasTag} - a canvas tagOrId
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  set tk_popupPriv($xfMenu,focus) ""
  set tk_popupPriv($xfMenu,grab) ""
  if {"$xfModifier" != ""} {
    set press "$xfModifier-"
    set motion "$xfModifier-"
    set release "Any-"
  } {
    set press ""
    set motion ""
    set release ""
  }

  bind $xfMenu "<${motion}B${xfButton}-Motion>"  "MenuPopupMotion $xfMenu %W %X %Y"
  bind $xfMenu "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  if {"$xfCanvasTag" == ""} {
    bind $xfW "<${press}ButtonPress-${xfButton}>"  "MenuPopupPost $xfMenu %X %Y"
    bind $xfW "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  } {
    $xfW bind $xfCanvasTag "<${press}ButtonPress-${xfButton}>"  "MenuPopupPost $xfMenu %X %Y"
    $xfW bind $xfCanvasTag "<${release}ButtonRelease-${xfButton}>"  "MenuPopupRelease $xfMenu %W"
  }
}
}


# Procedure: MenuPopupMotion
if {"[info procs MenuPopupMotion]" == ""} {
proc MenuPopupMotion { xfMenu xfW xfX xfY} {
# xf ignore me 7
##########
# Procedure: MenuPopupMotion
# Description: handle the popup menu motion
# Arguments: xfMenu - the topmost menu
#            xfW - the menu
#            xfX - the root x coordinate
#            xfY - the root x coordinate
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  if {"[info commands $xfW]" != "" && [winfo ismapped $xfW] &&
      "[winfo class $xfW]" == "Menu" &&
      [info exists tk_popupPriv($xfMenu,focus)] &&
      "$tk_popupPriv($xfMenu,focus)" != "" &&
      [info exists tk_popupPriv($xfMenu,grab)] &&
      "$tk_popupPriv($xfMenu,grab)" != ""} {
    set xfPopMinX [winfo rootx $xfW]
    set xfPopMaxX [expr $xfPopMinX+[winfo width $xfW]]
    if {$xfX >= $xfPopMinX && $xfX <= $xfPopMaxX} {
      $xfW activate @[expr $xfY-[winfo rooty $xfW]]
      if {![catch "$xfW entryconfig @[expr $xfY-[winfo rooty $xfW]] -menu" result]} {
        if {"[lindex $result 4]" != ""} {
          foreach binding [bind $xfMenu] {
            bind [lindex $result 4] $binding [bind $xfMenu $binding]
          }
        }
      }
    } {
      $xfW activate none
    }
  }
}
}


# Procedure: MenuPopupPost
if {"[info procs MenuPopupPost]" == ""} {
proc MenuPopupPost { xfMenu xfX xfY} {
# xf ignore me 7
##########
# Procedure: MenuPopupPost
# Description: post the popup menu
# Arguments: xfMenu - the menu
#            xfX - the root x coordinate
#            xfY - the root x coordinate
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv

  if {"[info commands $xfMenu]" != ""} {
    if {![info exists tk_popupPriv($xfMenu,focus)]} {
      set tk_popupPriv($xfMenu,focus) [focus]
    } {
      if {"$tk_popupPriv($xfMenu,focus)" == ""} {
        set tk_popupPriv($xfMenu,focus) [focus]
      }
    }
    set tk_popupPriv($xfMenu,grab) $xfMenu

    catch "$xfMenu activate none"
    catch "$xfMenu post $xfX $xfY"
    catch "focus $xfMenu"
    catch "grab -global $xfMenu"
  }
}
}


# Procedure: MenuPopupRelease
if {"[info procs MenuPopupRelease]" == ""} {
proc MenuPopupRelease { xfMenu xfW} {
# xf ignore me 7
##########
# Procedure: MenuPopupRelease
# Description: remove the popup menu
# Arguments: xfMenu - the topmost menu widget
#            xfW - the menu widget
# Returns: none
# Sideeffects: none
##########
  global tk_popupPriv
  global tkVersion

  if {"[info commands $xfW]" != "" && [winfo ismapped $xfW] &&
      "[winfo class $xfW]" == "Menu" &&
      [info exists tk_popupPriv($xfMenu,focus)] &&
      "$tk_popupPriv($xfMenu,focus)" != "" &&
      [info exists tk_popupPriv($xfMenu,grab)] &&
      "$tk_popupPriv($xfMenu,grab)" != ""} {
    if {$tkVersion >= 3.0} {
      catch "grab release $tk_popupPriv($xfMenu,grab)"
    } {
      catch "grab none"
    }
    catch "focus $tk_popupPriv($xfMenu,focus)"
    set tk_popupPriv($xfMenu,focus) ""
    set tk_popupPriv($xfMenu,grab) ""
    if {"[$xfW index active]" != "none"} {
      $xfW invoke active; catch "$xfMenu unpost"
    }
  }
  catch "$xfMenu unpost"
}
}


# Procedure: NoFunction
if {"[info procs NoFunction]" == ""} {
proc NoFunction { args} {
# xf ignore me 7
##########
# Procedure: NoFunction
# Description: do nothing (especially with scales and scrollbars)
# Arguments: args - a number of ignored parameters
# Returns: none
# Sideeffects: none
##########
}
}


# Procedure: SN
if {"[info procs SN]" == ""} {
proc SN { {xfName ""}} {
# xf ignore me 7
##########
# Procedure: SN
# Description: map a symbolic name to the widget path
# Arguments: xfName
# Returns: the symbolic name
# Sideeffects: none
##########

  SymbolicName $xfName
}
}


# Procedure: SymbolicName
if {"[info procs SymbolicName]" == ""} {
proc SymbolicName { {xfName ""}} {
# xf ignore me 7
##########
# Procedure: SymbolicName
# Description: map a symbolic name to the widget path
# Arguments: xfName
# Returns: the symbolic name
# Sideeffects: none
##########

  global symbolicName

  if {"$xfName" != ""} {
    set xfArrayName ""
    append xfArrayName symbolicName ( $xfName )
    if {![catch "set \"$xfArrayName\"" xfValue]} {
      return $xfValue
    } {
      if {"[info commands XFocError]" != ""} {
        XFProcError "Unknown symbolic name:\n$xfName"
      } {
        puts stderr "XF error: unknown symbolic name:\n$xfName"
      }
    }
  }
  return ""
}
}


# Procedure: Unalias
if {"[info procs Unalias]" == ""} {
proc Unalias { aliasName} {
# xf ignore me 7
##########
# Procedure: Unalias
# Description: remove an alias for a procedure
# Arguments: aliasName - the alias name to remove
# Returns: none
# Sideeffects: internalAliasList is updated, and the alias
#              proc is removed
##########
  global internalAliasList

  set xfIndex [lsearch $internalAliasList "$aliasName *"]
  if {$xfIndex != -1} {
    rename $aliasName ""
    set internalAliasList [lreplace $internalAliasList $xfIndex $xfIndex]
  }
}
}



# application parsing procedure
proc XFLocalParseAppDefs {xfAppDefFile} {
  global xfAppDefaults

  # basically from: Michael Moore
  if {[file exists $xfAppDefFile] &&
      [file readable $xfAppDefFile] &&
      "[file type $xfAppDefFile]" == "link"} {
    catch "file type $xfAppDefFile" xfType
    while {"$xfType" == "link"} {
      if {[catch "file readlink $xfAppDefFile" xfAppDefFile]} {
        return
      }
      catch "file type $xfAppDefFile" xfType
    }
  }
  if {!("$xfAppDefFile" != "" &&
        [file exists $xfAppDefFile] &&
        [file readable $xfAppDefFile] &&
        "[file type $xfAppDefFile]" == "file")} {
    return
  }
  if {![catch "open $xfAppDefFile r" xfResult]} {
    set xfAppFileContents [read $xfResult]
    close $xfResult
    foreach line [split $xfAppFileContents "\n"] {
      # backup indicates how far to backup.  It applies to the
      # situation where a resource name ends in . and when it
      # ends in *.  In the second case you want to keep the *
      # in the widget name for pattern matching, but you want
      # to get rid of the . if it is the end of the name. 
      set backup -2  
      set line [string trim $line]
      if {[string index $line 0] == "#" || "$line" == ""} {
        # skip comments and empty lines
        continue
      }
      set list [split $line ":"]
      set resource [string trim [lindex $list 0]]
      set i [string last "." $resource]
      set j [string last "*" $resource]
      if {$j > $i} { 
        set i $j
        set backup -1
      }
      incr i
      set name [string range $resource $i end]
      incr i $backup
      set widname [string range $resource 0 $i]
      set value [string trim [lindex $list 1]]
      if {"$widname" != "" && "$widname" != "*"} {
        # insert the widget and resourcename to the application
        # defaults list.
        if {![info exists xfAppDefaults]} {
          set xfAppDefaults ""
        }
        lappend xfAppDefaults [list $widname [string tolower $name] $value]
      }
    }
  }
}

# application loading procedure
proc XFLocalLoadAppDefs {{xfClasses ""} {xfPriority "startupFile"} {xfAppDefFile ""}} {
  global env

  if {"$xfAppDefFile" == ""} {
    set xfFileList ""
    if {[info exists env(XUSERFILESEARCHPATH)]} {
      append xfFileList [split $env(XUSERFILESEARCHPATH) :]
    }
    if {[info exists env(XAPPLRESDIR)]} {
      append xfFileList [split $env(XAPPLRESDIR) :]
    }
    if {[info exists env(XFILESEARCHPATH)]} {
      append xfFileList [split $env(XFILESEARCHPATH) :]
    }
    append xfFileList " /usr/lib/X11/app-defaults"
    append xfFileList " /usr/X11/lib/X11/app-defaults"

    foreach xfCounter1 $xfClasses {
      foreach xfCounter2 $xfFileList {
        set xfPathName $xfCounter2
        if {[regsub -all "%N" "$xfPathName" "$xfCounter1" xfResult]} {
          set xfPathName $xfResult
        }
        if {[regsub -all "%T" "$xfPathName" "app-defaults" xfResult]} {
          set xfPathName $xfResult
        }
        if {[regsub -all "%S" "$xfPathName" "" xfResult]} {
          set xfPathName $xfResult
        }
        if {[regsub -all "%C" "$xfPathName" "" xfResult]} {
          set xfPathName $xfResult
        }
        if {[file exists $xfPathName] &&
            [file readable $xfPathName] &&
            ("[file type $xfPathName]" == "file" ||
             "[file type $xfPathName]" == "link")} {
          catch "option readfile $xfPathName $xfPriority"
          if {"[info commands XFParseAppDefs]" != ""} {
            XFParseAppDefs $xfPathName
          } {
            if {"[info commands XFLocalParseAppDefs]" != ""} {
              XFLocalParseAppDefs $xfPathName
            }
          }
        } {
          if {[file exists $xfCounter2/$xfCounter1] &&
              [file readable $xfCounter2/$xfCounter1] &&
              ("[file type $xfCounter2/$xfCounter1]" == "file" ||
               "[file type $xfCounter2/$xfCounter1]" == "link")} {
            catch "option readfile $xfCounter2/$xfCounter1 $xfPriority"
            if {"[info commands XFParseAppDefs]" != ""} {
              XFParseAppDefs $xfCounter2/$xfCounter1
            } {
              if {"[info commands XFLocalParseAppDefs]" != ""} {
                XFLocalParseAppDefs $xfCounter2/$xfCounter1
              }
            }
          }
        }
      }
    }
  } {
    # load a specific application defaults file
    if {[file exists $xfAppDefFile] &&
        [file readable $xfAppDefFile] &&
        ("[file type $xfAppDefFile]" == "file" ||
         "[file type $xfAppDefFile]" == "link")} {
      catch "option readfile $xfAppDefFile $xfPriority"
      if {"[info commands XFParseAppDefs]" != ""} {
        XFParseAppDefs $xfAppDefFile
      } {
        if {"[info commands XFLocalParseAppDefs]" != ""} {
          XFLocalParseAppDefs $xfAppDefFile
        }
      }
    }
  }
}


# application setting procedure
proc XFLocalSetAppDefs {{xfWidgetPath "."}} {
  global xfAppDefaults

  if {![info exists xfAppDefaults]} {
    return
  }
  foreach xfCounter $xfAppDefaults {
    if {"$xfCounter" == ""} {
      break
    }
    set widname [lindex $xfCounter 0]
    if {[string match $widname ${xfWidgetPath}] ||
        [string match "${xfWidgetPath}*" $widname]} {
      set name [string tolower [lindex $xfCounter 1]]
      set value [lindex $xfCounter 2]
      # Now lets see how many tcl commands match the name
      # pattern specified.
      set widlist [info command $widname]
      if {"$widlist" != ""} {
        foreach widget $widlist {
          # make sure this command is a widget.
          if {![catch "winfo id $widget"] &&
              [string match "${xfWidgetPath}*" $widget]} {
            catch "$widget configure -$name $value" 
          }
        }
      }
    }
  }
}



# startup source
proc StartupSrc {args} {

}



# end source
proc EndSrc {} {
global argc argv argv0
global nameServerPort nameOfNameServer
global retrievingToolPort

set nameServerPort 8765
set retrievingToolPort 0

for {set counter 0} {$counter < $argc} {incr counter 1} {
  case [string tolower [lindex $argv $counter]] in {

    {"-nameserverport" "-nsp"} {
      incr counter 1
      set nameServerPort "[lindex $argv $counter]" 	
    }
    {"-nameserver" "-ns"} {
      incr counter 1
      set nameOfNameServer "[lindex $argv $counter]"
    }
    {"-retrievingtoolport" "-rtp"} {
      incr counter 1
      set retrievingToolPort "[lindex $argv $counter]" 	
    }
    {default} {
      puts "SYNOPSIS : $argv0"
      puts {           -nameserver <host address> [-nameserverport <int>]}
      puts {           [-retrievingtoolport <int>]}
      puts {or}
      puts "SYNOPSIS : $argv0"
      puts {           -ns <host address> [-nsp <int>] [-rtp <int>}
      exit
    }
  }
}

install
}

# prepare auto loading
global auto_path
global tk_library
global xfLoadPath
foreach xfElement [eval list [split $xfLoadPath :] $auto_path] {
  if {[file exists $xfElement/tclIndex]} {
    lappend auto_path $xfElement
  }
}
catch "unset auto_index"
catch "unset auto_oldpath"
catch "unset auto_execs"

XFLocalIncludeModule list
XFLocalIncludeModule makeRPCClient
XFLocalIncludeModule makeRPCServer
XFLocalIncludeModule fatalError
XFLocalIncludeModule RetrievingTool.procs 
XFLocalIncludeModule RetrievingTool.rpc
XFLocalIncludeModule Copyright


# initialize global variables
proc InitGlobals {} {
  global {.frame1.frame5.frame4.frame.listbox1size}
  set {.frame1.frame5.frame4.frame.listbox1size} {0}
  global {.frame1.frame5.frame4.frame.listbox1wholeList}
  set {.frame1.frame5.frame4.frame.listbox1wholeList} {}
  global {.frame15.frame21.frame16.frame3.frame.listbox1pattern}
  set {.frame15.frame21.frame16.frame3.frame.listbox1pattern} {*}
  global {.frame15.frame21.frame16.frame3.frame.listbox1patterntype}
  set {.frame15.frame21.frame16.frame3.frame.listbox1patterntype} {glob style}
  global {.frame15.frame21.frame16.frame3.frame.listbox1size}
  set {.frame15.frame21.frame16.frame3.frame.listbox1size} {1}
  global {.frame15.frame21.frame16.frame3.frame.listbox1wholeList}
  set {.frame15.frame21.frame16.frame3.frame.listbox1wholeList} {{bad: file}}
  global {.frame15.frame21.frame17.frame4.frame.listbox1pattern}
  set {.frame15.frame21.frame17.frame4.frame.listbox1pattern} {*}
  global {.frame15.frame21.frame17.frame4.frame.listbox1patterntype}
  set {.frame15.frame21.frame17.frame4.frame.listbox1patterntype} {glob style}
  global {.frame15.frame21.frame17.frame4.frame.listbox1size}
  set {.frame15.frame21.frame17.frame4.frame.listbox1size} {0}
  global {.frame15.frame21.frame17.frame4.frame.listbox1wholeList}
  set {.frame15.frame21.frame17.frame4.frame.listbox1wholeList} {}
  global {.frame15.frame21.frame20.frame9.frame.listbox1pattern}
  set {.frame15.frame21.frame20.frame9.frame.listbox1pattern} {*}
  global {.frame15.frame21.frame20.frame9.frame.listbox1patterntype}
  set {.frame15.frame21.frame20.frame9.frame.listbox1patterntype} {glob style}
  global {.frame15.frame21.frame20.frame9.frame.listbox1size}
  set {.frame15.frame21.frame20.frame9.frame.listbox1size} {0}
  global {.frame15.frame21.frame20.frame9.frame.listbox1wholeList}
  set {.frame15.frame21.frame20.frame9.frame.listbox1wholeList} {}
  global {NameOfImageserver}
  set {NameOfImageserver} {bad}
  global {Selected images}
  set {Selected images} {label10}
  global {actdir}
  set {actdir} {}
  global {from.listbox}
  set {from.listbox} {.frame15.frame21.frame17.frame4.frame.listbox1}
  global {from.mode}
  set {from.mode} {short}
  global {i}
  set {i} {39}
  global {imageServerPort}
  set {imageServerPort} {8766}
  global {is.listbox}
  set {is.listbox} {.frame15.frame21.frame16.frame3.frame.listbox1}
  global {is.mode}
  set {is.mode} {short}
  global {m}
  set {m} {Dir Browsing}
  global {mode}
  set {mode} {dir}
  global {nameOfMine}
  set {nameOfMine} {icsib77.ICSI.Berkeley.EDU}
  global {nameOfNameServer}
  set {nameOfNameServer} {entry4}
  global {nameServerPort}
  set {nameServerPort} {8765}
  global {result}
  set {result} {}
  global {retrievingToolPort}
  set {retrievingToolPort} {3482}
  global {search pattern}
  set {search pattern} {}
  global {search.pattern}
  set {search.pattern} {}
  global {size}
  set {size} {98}
  global {sockid}
  set {sockid} {Couldn't open connection to entry4:8765 : Invalid argument}
  global {statusWord}
  set {statusWord} {}

  set {temp} {bad file identifier "Couldn't open connection to entry4:8765 : Invalid argument"}
  global {to.listbox}
  set {to.listbox} {.frame15.frame21.frame20.frame9.frame.listbox1}
  global {to.mode}
  set {to.mode} {short}

  # please don't modify the following
  # variables. They are needed by xf.
  global {autoLoadList}
  set {autoLoadList(main.tcl)} {0}
  global {internalAliasList}
  set {internalAliasList} {}
  global {moduleList}
  set {moduleList(main.tcl)} {}
  global {preloadList}
  set {preloadList(xfInternal)} {}
  global {symbolicName}
  set {symbolicName(root)} {.}
  global {xfWmSetPosition}
  set {xfWmSetPosition} {}
  global {xfWmSetSize}
  set {xfWmSetSize} {.}
  global {xfAppDefToplevels}
  set {xfAppDefToplevels} {}
}

# initialize global variables
InitGlobals

# display/remove toplevel windows.
ShowWindow.

# load default bindings.
if {[info exists env(XF_BIND_FILE)] &&
    "[info procs XFShowHelp]" == ""} {
  source $env(XF_BIND_FILE)
}

# end source
EndSrc

# eof
#

